<?php
/**
 * The homepage layouts
 *
 * @package Startup
 */

defined( 'WPINC' ) || exit;

/**
 * Class for featured layouts.
 */
class Startup_Homepage_Layouts extends Startup_Base {

	/**
	 * Current layout.
	 *
	 * @var string
	 */
	public $current = null;

	/**
	 * Hold sections.
	 *
	 * @var array
	 */
	private $sections = null;

	/**
	 * The Construct
	 */
	public function __construct() {
		$this->sections = startup_get_settings( 'homepage_layout' );
	}

	/**
	 * Render layout
	 */
	public function render() {

		if ( empty( $this->sections ) ) {
			$this->current = array(
				'home_layout'    => 'three-column-features',
				'home_unique_id' => 'nothing',
			);

			get_template_part( 'template-parts/homepage/home', 'three-column-features' );
			return;
		}

		foreach ( $this->sections as $section ) :

			$section = wp_parse_args( array_filter( $section ), array(
				'home_layout'    => '',
				'home_unique_id' => '',
			) );

			$layout        = $section['home_layout'];
			$this->current = array(
				'home_layout'    => $layout,
				'home_unique_id' => $section['home_unique_id'],
			);
			get_template_part( 'template-parts/homepage/home', $layout );

		endforeach;
	}

	/**
	 * Genrate post_container classes
	 */
	public function get_post_container_class() {
		$classes   = array();
		$classes[] = 'layout-' . $this->current['home_unique_id'];
		$classes[] = $this->current['home_layout'] . '-container';
		$classes[] = 'clearfix';

		echo join( ' ', $classes );
	}

	/*
	 * 3 column features
	 *
	 * */
	public function three_column_features() {

		$threefeatures = startup_get_settings( 'home_threefeatures_' . $this->current['home_unique_id'] );

		if ( empty( $threefeatures ) && ! is_array( $threefeatures ) ) {
			return;
		}
		?>

		<section class="threefeatures-section <?php $this->get_post_container_class(); ?> clearfix">

			<div class="container clearfix">

				<?php

				$i = 0;

				foreach ( $threefeatures as $feature ) {
					$icon         = ! empty( $feature[ 'threefeatures_icon_' . $this->current['home_unique_id'] ] ) ? sprintf( '<div class="feature-icon fa fa-%1$s"></div>', $feature[ 'threefeatures_icon_' . $this->current['home_unique_id'] ] ) : '';
					$title        = ! empty( $feature[ 'threefeatures_title_' . $this->current['home_unique_id'] ] ) ? sprintf( '<h3>%1$s</h3>', $feature[ 'threefeatures_title_' . $this->current['home_unique_id'] ] ) : '';
					$text         = ! empty( $feature[ 'threefeatures_text_' . $this->current['home_unique_id'] ] ) ? sprintf( '<p class="text">%1$s</p>', $feature[ 'threefeatures_text_' . $this->current['home_unique_id'] ] ) : '';
					$archor_start = ! empty( $feature[ 'threefeatures_link_' . $this->current['home_unique_id'] ] ) ? sprintf( '<a href="%1$s">', $feature[ 'threefeatures_link_' . $this->current['home_unique_id'] ] ) : '';
					$link_text    = ! empty( $feature[ 'threefeatures_link_text_' . $this->current['home_unique_id'] ] ) ? sprintf(
						'<p class="link-text"><span>%1$s</span><svg version="1.1" id="Capa_1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
    				 viewBox="0 0 31.49 31.49" style="enable-background:new 0 0 31.49 31.49;" xml:space="preserve"><path d="M21.205,5.007c-0.429-0.444-1.143-0.444-1.587,0c-0.429,0.429-0.429,1.143,0,1.571l8.047,8.047H1.111
    				C0.492,14.626,0,15.118,0,15.737c0,0.619,0.492,1.127,1.111,1.127h26.554l-8.047,8.032c-0.429,0.444-0.429,1.159,0,1.587
    c0.444,0.444,1.159,0.444,1.587,0l9.952-9.952c0.444-0.429,0.444-1.143,0-1.571L21.205,5.007z"/></svg></p>',
					$feature[ 'threefeatures_link_text_' . $this->current['home_unique_id'] ] ) : '';
					$archor_end   = ! empty( $feature[ 'threefeatures_link_' . $this->current['home_unique_id'] ] ) ? '</a>' : '';
					printf( '<div class="feature-item item-' . ++$i . '">%1$s%2$s%3$s%4$s%5$s%6$s</div>', $icon, $title, $text, $archor_start, $link_text, $archor_end );
				}

				?>

			</div><!-- .container -->

		</section>
		<?php
	}

	/*
	 * 2 column features
	 *
	 * */
	public function two_column_features() {

		$heading     = startup_get_settings( 'twofeatures_heading_' . $this->current['home_unique_id'] );
		$subheading  = startup_get_settings( 'twofeatures_subheading_' . $this->current['home_unique_id'] );
		$twofeatures = startup_get_settings( 'home_twofeatures_' . $this->current['home_unique_id'] );
		$img         = startup_get_settings( 'twofeatures_image_' . $this->current['home_unique_id'] );
		$position    = startup_get_settings( 'twofeatures_content_position_' . $this->current['home_unique_id'] );

		if ( empty( $twofeatures ) && ! is_array( $twofeatures ) ) {
			return;
		}
		?>

		<section class="twofeatures-section <?php $this->get_post_container_class(); ?> clearfix">

			<div class="container clearfix">

				<div class="twofeatures-section-content content-<?php echo $position; ?>">
					<?php
					if ( ! empty( $img ) ) {
						?>
						<div class="twofeatures-image">
							<?php printf( '<img src="%1$s">', $img ); ?>
						</div>
						<?php
					}
					?>
					<div class="twofeatures-items">
						<?php
						if ( $heading || $subheading ) {
							?>
								<div class="twofeatures-heading-section">
							<?php
						}
						if ( $heading ) {
							printf(
								'<h2>%s</h2>',
								$heading
							);
						}
						if ( $subheading ) {
							printf(
								'<p class="sub-heading">%s</p>',
								$subheading
							);
						}
						if ( $heading || $subheading ) {
							?>
						</div>
							<?php
						}
						$i = 0;
						foreach ( $twofeatures as $feature ) {
							$icon  = ! empty( $feature[ 'twofeatures_icon_' . $this->current['home_unique_id'] ] ) ? sprintf( '<div class="feature-icon fa fa-%1$s"></div>', $feature[ 'twofeatures_icon_' . $this->current['home_unique_id'] ] ) : '';
							$title = ! empty( $feature[ 'twofeatures_title_' . $this->current['home_unique_id'] ] ) ? sprintf( '<h3>%1$s</h3>', $feature[ 'twofeatures_title_' . $this->current['home_unique_id'] ] ) : '';
							$text  = ! empty( $feature[ 'twofeatures_text_' . $this->current['home_unique_id'] ] ) ? sprintf( '<p class="text">%1$s</p>', $feature[ 'twofeatures_text_' . $this->current['home_unique_id'] ] ) : '';
							printf( '<div class="twofeature-item item-' . ++$i . '">%1$s%2$s%3$s</div>', $icon, $title, $text );
						}

						// 2 Column Features Button.
						if ( startup_get_settings( 'twofeatures_button_' . $this->current['home_unique_id'] ) && ! empty( startup_get_settings( 'twofeatures_button_url_' . $this->current['home_unique_id'] ) ) ) {
							printf(
								'<div class="twofeatures-button"><a href="%1$s" class="button"><span>%2$s</span><svg version="1.1" id="Capa_1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
								 viewBox="0 0 31.49 31.49" style="enable-background:new 0 0 31.49 31.49;" xml:space="preserve"><path d="M21.205,5.007c-0.429-0.444-1.143-0.444-1.587,0c-0.429,0.429-0.429,1.143,0,1.571l8.047,8.047H1.111
								C0.492,14.626,0,15.118,0,15.737c0,0.619,0.492,1.127,1.111,1.127h26.554l-8.047,8.032c-0.429,0.444-0.429,1.159,0,1.587
					c0.444,0.444,1.159,0.444,1.587,0l9.952-9.952c0.444-0.429,0.444-1.143,0-1.571L21.205,5.007z"/></svg></a></div>',
								startup_get_settings( 'twofeatures_button_url_' . $this->current['home_unique_id'] ),
								startup_get_settings( 'twofeatures_button_text_' . $this->current['home_unique_id'] )
							);
						}
						?>
					</div>
				</div>

			</div><!-- .container -->

		</section>
		<?php
	}

	/*
	 * 4 column features
	 *
	 * */
	public function four_column_features() {

		$heading      = startup_get_settings( 'fourfeatures_heading_' . $this->current['home_unique_id'] );
		$subheading   = startup_get_settings( 'fourfeatures_subheading_' . $this->current['home_unique_id'] );
		$fourfeatures = startup_get_settings( 'home_fourfeatures_' . $this->current['home_unique_id'] );

		if ( empty( $fourfeatures ) && ! is_array( $fourfeatures ) ) {
			return;
		}
		?>

		<section class="fourfeatures-section <?php $this->get_post_container_class(); ?> clearfix">
			<?php
			if ( $heading || $subheading ) {
				?>
					<div class="fourfeatures-heading-section">
						<div class="container">
				<?php
			}
			if ( $heading ) {
				printf(
					'<h2>%s</h2>',
					$heading
				);
			}
			if ( $subheading ) {
				printf(
					'<p class="sub-heading">%s</p>',
					$subheading
				);
			}
			if ( $heading || $subheading ) {
				?>
				</div>
			</div>
				<?php
			}
			?>
			<div class="container clearfix">

				<div class="fourfeatures-section-content">
					<?php
					$i = 0;
					foreach ( $fourfeatures as $feature ) {
						$icon  = ! empty( $feature[ 'fourfeatures_icon_' . $this->current['home_unique_id'] ] ) ? sprintf( '<div class="feature-icon fa fa-%1$s"></div>', $feature[ 'fourfeatures_icon_' . $this->current['home_unique_id'] ] ) : '';
						$title = ! empty( $feature[ 'fourfeatures_title_' . $this->current['home_unique_id'] ] ) ? sprintf( '<h3>%1$s</h3>', $feature[ 'fourfeatures_title_' . $this->current['home_unique_id'] ] ) : '';
						$text  = ! empty( $feature[ 'fourfeatures_text_' . $this->current['home_unique_id'] ] ) ? sprintf( '<p class="text">%1$s</p>', $feature[ 'fourfeatures_text_' . $this->current['home_unique_id'] ] ) : '';
						printf( '<div class="fourfeature-item item-' . ++$i . '">%1$s%2$s%3$s</div>', $icon, $title, $text );
					}

					// 2 Column Features Button.
					if ( startup_get_settings( 'fourfeatures_button_' . $this->current['home_unique_id'] ) && ! empty( startup_get_settings( 'fourfeatures_button_url_' . $this->current['home_unique_id'] ) ) ) {
						printf(
							'<div class="fourfeatures-button"><a href="%1$s" class="button"><span>%2$s</span><svg version="1.1" id="Capa_1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
							 viewBox="0 0 31.49 31.49" style="enable-background:new 0 0 31.49 31.49;" xml:space="preserve"><path d="M21.205,5.007c-0.429-0.444-1.143-0.444-1.587,0c-0.429,0.429-0.429,1.143,0,1.571l8.047,8.047H1.111
							C0.492,14.626,0,15.118,0,15.737c0,0.619,0.492,1.127,1.111,1.127h26.554l-8.047,8.032c-0.429,0.444-0.429,1.159,0,1.587
				c0.444,0.444,1.159,0.444,1.587,0l9.952-9.952c0.444-0.429,0.444-1.143,0-1.571L21.205,5.007z"/></svg></a></div>',
							startup_get_settings( 'fourfeatures_button_url_' . $this->current['home_unique_id'] ),
							startup_get_settings( 'fourfeatures_button_text_' . $this->current['home_unique_id'] )
						);
					}
					?>
				</div>

			</div><!-- .container -->

		</section>
		<?php
	}

	/*
	 * CTA
	 *
	 * */
	public function cta_features() {

		$heading    = startup_get_settings( 'cta_title_' . $this->current['home_unique_id'] );
		$subheading = startup_get_settings( 'cta_text_' . $this->current['home_unique_id'] );

		?>

		<section class="cta-section <?php $this->get_post_container_class(); ?> clearfix">

			<div class="container clearfix">
				<?php
				if ( $heading || $subheading ) {
					?>
						<div class="cta-left">
					<?php
				}
				if ( $heading ) {
					printf(
						'<h3>%s</h3>',
						$heading
					);
				}
				if ( $subheading ) {
					printf(
						'<p>%s</p>',
						$subheading
					);
				}
				if ( $heading || $subheading ) {
					?>
				</div>
					<?php
				}

				// CTA Button.
				if ( startup_get_settings( 'cta_button_' . $this->current['home_unique_id'] ) && ! empty( startup_get_settings( 'cta_button_url_' . $this->current['home_unique_id'] ) ) ) {
					printf(
						'<div class="cta-button"><a href="%1$s" class="button">%2$s</a></div>',
						startup_get_settings( 'cta_button_url_' . $this->current['home_unique_id'] ),
						startup_get_settings( 'cta_button_text_' . $this->current['home_unique_id'] )
					);
				}
				?>

			</div><!-- .container -->

		</section>
		<?php
	}

	/*
	 * Pricing Table
	 *
	 * */
	public function pricing_features() {

		$heading    = startup_get_settings( 'pricing_heading_' . $this->current['home_unique_id'] );
		$subheading = startup_get_settings( 'pricing_subheading_' . $this->current['home_unique_id'] );
		$pricing    = startup_get_settings( 'home_pricing_' . $this->current['home_unique_id'] );

		if ( empty( $pricing ) && ! is_array( $pricing ) ) {
			return;
		}
		?>

		<section class="pricing-section <?php $this->get_post_container_class(); ?> clearfix">

			<div class="container clearfix">

				<?php
				if ( $heading || $subheading ) {
					?>
						<div class="pricing-heading-section">
					<?php
				}
				if ( $heading ) {
					printf(
						'<h2>%s</h2>',
						$heading
					);
				}
				if ( $subheading ) {
					printf(
						'<p class="sub-heading">%s</p>',
						$subheading
					);
				}
				if ( $heading || $subheading ) {
					?>
				</div>
					<?php
				}
				$i = 0;
				foreach ( $pricing as $price ) {
					echo '<div class="pricing-item item-' . ++$i . '">';
					$icon   = ! empty( $price[ 'pricing_icon_' . $this->current['home_unique_id'] ] ) ? sprintf( '<div class="pricing-icon fa fa-%1$s"></div>', $price[ 'pricing_icon_' . $this->current['home_unique_id'] ] ) : '';
					$title  = ! empty( $price[ 'pricing_title_' . $this->current['home_unique_id'] ] ) ? sprintf( '<h3>%1$s</h3>', $price[ 'pricing_title_' . $this->current['home_unique_id'] ] ) : '';
					$text   = ! empty( $price[ 'pricing_text_' . $this->current['home_unique_id'] ] ) ? sprintf( '%1$s', wpautop( $price[ 'pricing_text_' . $this->current['home_unique_id'] ] ) ) : '';
					$amount = ! empty( $price[ 'pricing_amount_' . $this->current['home_unique_id'] ] ) ? sprintf( '<div class="pricing-amount">%1$s</div>', $price[ 'pricing_amount_' . $this->current['home_unique_id'] ] ) : '';
					printf( '%1$s%2$s<div class="pricing-list">%3$s</div>%4$s', $icon, $title, $text, $amount );
					if ( ! empty( $price[ 'pricing_button_url_' . $this->current['home_unique_id'] ] ) ) {
						printf(
							'<div class="pricing-button"><a href="%1$s" class="button">%2$s</a></div>',
							$price[ 'pricing_button_url_' . $this->current['home_unique_id'] ],
							$price[ 'pricing_button_text_' . $this->current['home_unique_id'] ]
						);
					}
					echo '</div>';
				}
				?>

			</div><!-- .container -->

		</section>
		<?php
	}

	/*
	 * Clients
	 *
	 * */
	public function clients_features() {

		$heading    = startup_get_settings( 'clients_heading_' . $this->current['home_unique_id'] );
		$subheading = startup_get_settings( 'clients_subheading_' . $this->current['home_unique_id'] );
		//Clients items
		$clients = startup_get_settings( 'home_clients_' . $this->current['home_unique_id'] );

		if ( empty( $clients ) && ! is_array( $clients ) ) {
			return;
		}
		?>

		<section class="clients-section <?php $this->get_post_container_class(); ?> clearfix">
			<?php
			if ( $heading || $subheading ) {
				?>
					<div class="clients-heading-section">
						<div class="container">
				<?php
			}
			if ( $heading ) {
				printf(
					'<h2>%s</h2>',
					$heading
				);
			}
			if ( $subheading ) {
				printf(
					'<p class="sub-heading">%s</p>',
					$subheading
				);
			}
			if ( $heading || $subheading ) {
				?>
			</div></div>
				<?php
			}
			?>
			<div class="clients-section-items">

				<div class="container clearfix">

					<ul>

					<?php

					foreach ( $clients as $client ) {
						$img          = ! empty( $client[ 'client_image_' . $this->current['home_unique_id'] ] ) ? sprintf( '<img src="%1$s" alt="%2$s">', $client[ 'client_image_' . $this->current['home_unique_id'] ], $client[ 'client_title_' . $this->current['home_unique_id'] ] ) : '';
						$archor_start = ! empty( $client[ 'client_link_' . $this->current['home_unique_id'] ] ) ? sprintf( '<a href="%1$s">', $client[ 'client_link_' . $this->current['home_unique_id'] ] ) : '';
						$archor_end   = ! empty( $client[ 'client_link_' . $this->current['home_unique_id'] ] ) ? '</a>' : '';
						printf( '<li class="client-item">%1$s%2$s%3$s</li>', $archor_start, $img, $archor_end );
					}

					?>

				</ul>

				</div><!-- .container -->
			</div>

		</section>
		<?php
	}

	/*
	 * Testimonials
	 *
	 * */
	public function testimonials_features() {

		$heading      = startup_get_settings( 'testimonials_heading_' . $this->current['home_unique_id'] );
		$subheading   = startup_get_settings( 'testimonials_subheading_' . $this->current['home_unique_id'] );
		$testimonials = startup_get_settings( 'home_testimonials_' . $this->current['home_unique_id'] );

		if ( empty( $testimonials ) && ! is_array( $testimonials ) ) {
			return;
		}
		?>

		<section class="testimonials-section <?php $this->get_post_container_class(); ?> clearfix">

			<div class="container clearfix">

				<?php
				if ( $heading || $subheading ) {
					?>
						<div class="testimonials-heading-section">
					<?php
				}
				if ( $heading ) {
					printf(
						'<h2>%s</h2>',
						$heading
					);
				}
				if ( $subheading ) {
					printf(
						'<p class="sub-heading">%s</p>',
						$subheading
					);
				}
				if ( $heading || $subheading ) {
					?>
				</div>
					<?php
				}
				?>
				<div class="testimonials-section-items">
					<?php
					foreach ( $testimonials as $testimonial ) {
						$archor_start = ! empty( $testimonial[ 'customer_link_' . $this->current['home_unique_id'] ] ) ? sprintf( '<a href="%1$s">', $testimonial[ 'customer_link_' . $this->current['home_unique_id'] ] ) : '';
						$archor_end   = ! empty( $testimonial[ 'customer_link_' . $this->current['home_unique_id'] ] ) ? '</a>' : '';
						$img          = ! empty( $testimonial[ 'customer_image_' . $this->current['home_unique_id'] ] ) ? sprintf( '<img src="%1$s" alt="%2$s">', $testimonial[ 'customer_image_' . $this->current['home_unique_id'] ], $testimonial[ 'customer_title_' . $this->current['home_unique_id'] ] ) : '';
						$title        = ! empty( $testimonial[ 'customer_title_' . $this->current['home_unique_id'] ] ) ? sprintf( '<h3>%1$s</h3>', $testimonial[ 'customer_title_' . $this->current['home_unique_id'] ] ) : '';
						$profession   = ! empty( $testimonial[ 'customer_profession_' . $this->current['home_unique_id'] ] ) ? sprintf( '<p class="customer-profession">%1$s</p>', $testimonial[ 'customer_profession_' . $this->current['home_unique_id'] ] ) : '';
						$desc         = ! empty( $testimonial[ 'customer_description_' . $this->current['home_unique_id'] ] ) ? sprintf( '<p class="customer-description">%1$s</p>', $testimonial[ 'customer_description_' . $this->current['home_unique_id'] ] ) : '';
						printf( '<div class="testimonial-item">%1$s%2$s%3$s%4$s%5$s%6$s</div>', $archor_start, $img, $title, $archor_end, $profession, $desc );
					}
					?>
				</div>

			</div><!-- .container -->

		</section>
		<?php
	}

	/*
	 * Counters
	 *
	 * */
	public function counters_features() {

		$heading    = startup_get_settings( 'counters_heading_' . $this->current['home_unique_id'] );
		$subheading = startup_get_settings( 'counters_subheading_' . $this->current['home_unique_id'] );
		$counters   = startup_get_settings( 'home_counters_' . $this->current['home_unique_id'] );

		if ( empty( $counters ) && ! is_array( $counters ) ) {
			return;
		}
		?>

		<section class="counters-section <?php $this->get_post_container_class(); ?> clearfix">

			<div class="container clearfix">

				<?php
				if ( $heading || $subheading ) {
					?>
						<div class="counters-heading-section">
					<?php
				}
				if ( $heading ) {
					printf(
						'<h2>%s</h2>',
						$heading
					);
				}
				if ( $subheading ) {
					printf(
						'<p class="sub-heading">%s</p>',
						$subheading
					);
				}
				if ( $heading || $subheading ) {
					?>
				</div>
					<?php
				}
				?>
				<div class="counters-items">
					<?php
					foreach ( $counters as $counter ) {
						$number = ! empty( $counter[ 'counter_number_' . $this->current['home_unique_id'] ] ) ? sprintf( '<p class="counter counter-number">%1$s</p>', $counter[ 'counter_number_' . $this->current['home_unique_id'] ] ) : '';
						$title  = ! empty( $counter[ 'counter_title_' . $this->current['home_unique_id'] ] ) ? sprintf( '<h3>%1$s</h3>', $counter[ 'counter_title_' . $this->current['home_unique_id'] ] ) : '';
						printf( '<div class="counter-item">%1$s%2$s</div>', $number, $title );
					}
					?>
				</div>

			</div><!-- .container -->

		</section>
		<?php
	}

	/*
	 * Blog
	 *
	 * */
	public function blog_section_features() {

		$heading    = startup_get_settings( 'blog_section_heading_' . $this->current['home_unique_id'] );
		$subheading = startup_get_settings( 'blog_section_subheading_' . $this->current['home_unique_id'] );

		$post_num = ! empty( startup_get_settings( 'blog_section_postnum_' . $this->current['home_unique_id'] ) ) ? startup_get_settings( 'blog_section_postnum_' . $this->current['home_unique_id'] ) : '3';

		?>

		<section class="blog-section <?php $this->get_post_container_class(); ?> clearfix">

			<div class="container clearfix">
				<?php
				if ( $heading || $subheading ) {
					?>
						<div class="blog-heading-section">
					<?php
				}
				if ( $heading ) {
					printf(
						'<h2>%s</h2>',
						$heading
					);
				}
				if ( $subheading ) {
					printf(
						'<p class="sub-heading">%s</p>',
						$subheading
					);
				}
				if ( $heading || $subheading ) {
					?>
				</div>
					<?php
				}

				echo '<div class="layout-grid">';

				global $wp_query;
				$wp_query = new WP_Query( array( 'posts_per_page' => $post_num ) );

				while ( have_posts() ) :
					the_post();
					echo '<article class="latestPost excerpt">';
					?>
						<a href="<?php echo esc_url( get_the_permalink() ); ?>" title="<?php echo esc_attr( get_the_title() ); ?>" id="featured-thumbnail" class="post-image post-image-left">
							<div class="featured-thumbnail">
								<?php the_post_thumbnail( 'startup-widgetfull', array( 'title' => '' ) ); ?>
							</div>
						</a>
						<div class="wrapper">
							<header>
							<?php
							printf(
								'<h3 class="title"><a href="%1$s">%2$s</a></h3>',
								get_permalink(),
								get_the_title()
							);
							?>
							</header>
							<?php startup_the_post_meta( 'front', $this->current['home_unique_id'] ); ?>
							<div class="front-view-content">
								<?php
								if ( empty( startup_excerpt() ) ) {
									echo startup_truncate( get_the_content(), '28', 'words' );
								} else {
									echo startup_excerpt( '28' );
								}
								?>
							</div>
						</div>
					<?php
					echo '</article>';
				endwhile;

				echo '</div>';
				?>

			</div><!-- .container -->

		</section>
		<?php
	}

}
