<?php
/**
 * Sidebars
 *
 * @package Startup
 */

defined( 'WPINC' ) || exit;

/**
 * Single sections
 */
class Startup_Single_Sections extends Startup_Base {

	public function render() {
		?>
		<article class="<?php startup_article_class(); ?>">
			<?php
			if ( 'mts_nosidebar' !== mts_custom_sidebar() ) {
				$sidebar = startup_custom_sidebar_layout();
			} else {
				$sidebar = 'nosidebar';
			}
			?>
			<div id="content_box" class="<?php echo $sidebar; ?>">
				<?php
				// Elementor 'single' location.
				if ( ! function_exists( 'elementor_theme_do_location' ) || ! elementor_theme_do_location( 'single' ) ) {
					if ( have_posts() ) :
						while ( have_posts() ) :
							the_post();
							$img_size = startup_get_settings( 'featured_image_size' );
							?>
						<div id="post-<?php the_ID(); ?>" <?php post_class( 'g post' . isset( $img_size ) ? 'header-style-' . $img_size : '' ); ?>>
							<?php
							if ( startup_get_settings( 'mts_breadcrumb' ) ) {
								startup_breadcrumbs();
							}
							// Single post parts ordering.
							if ( ( null !== startup_get_settings( 'mts_single_post_layout' ) ) && is_array( startup_get_settings( 'mts_single_post_layout' ) ) && array_key_exists( 'enabled', startup_get_settings( 'mts_single_post_layout' ) ) ) {
								$single_post_parts = startup_get_settings( 'mts_single_post_layout' )['enabled'];
							} else {
								$single_post_parts = array(
									'content'   => 'content',
									'related'   => 'related',
									'author'    => 'author',
									'subscribe' => 'subscribe',
								);
							}

							foreach ( $single_post_parts as $part => $label ) {
								switch ( $part ) {
									case 'content':
										startup()->single_sections->single_post();
										break;

									case 'tags':
										startup_post_tags( '<div class="tags"><span class="tagtext">' . esc_html__( 'Tags: ', 'startup' ) . '</span>', '' );
										break;

									case 'related':
										if ( 'default' === startup_get_settings( 'related_posts_position' ) ) {
											startup_related_posts();
										}
										break;

									// Author box.
									case 'author':
										startup()->single_sections->single_author_section();
										break;

									// Subscribe box.
									case 'subscribe':
										startup()->single_sections->single_subscribe_box();
										break;
								}
							}
							?>
						</div><!--.g post-->
							<?php
								// Comment area.
								comments_template( '', true );

					endwhile;
				endif; /* end loop */
				}
				?>
			</div>
		</article>
		<?php
	}

	public function single_post() {
		?>
		<div class="single_post">

			<?php startup_action( 'single_post_header' ); ?>

			<div class="post-single-content box mark-links entry-content">

				<?php
				$this->single_post_ads( 'above' );

				$this->single_post_social_icons( 'above' );
				?>

				<div class="thecontent">
					<?php the_content(); ?>
				</div>

				<?php
				$this->single_post_pagination();

				$this->single_post_ads( 'below' );

				$this->single_post_social_icons( 'below' );
				?>

			</div><!--.post-single-content-->
		</div><!--.single_post-->
		<?php
	}

	public function single_post_pagination() {
		// Single Post Pagination.
		$args = array(
			'before'           => '<div class="pagination">',
			'after'            => '</div>',
			'link_before'      => '<span class="current"><span class="currenttext">',
			'link_after'       => '</span></span>',
			'next_or_number'   => 'next_and_number',
			'nextpagelink'     => '<i class="fa fa-chevron-right"></i>',
			'previouspagelink' => '<i class="fa fa-chevron-left"></i>',
			'pagelink'         => '%',
			'echo'             => 1,
		);
		wp_link_pages( $args );
	}

	public function single_author_section() {
	?>
		<div class="postauthor">

			<?php
			// Author box title.
			$author_title = startup_get_settings( 'author_box_title' );
			if ( $author_title ) {
				echo '<h4>' . $author_title . '</h4>';
			}
			// Author gravatar.
			if ( function_exists( 'get_avatar' ) ) {
				echo get_avatar( get_the_author_meta( 'email' ), '100' ); // Gravatar size.
			}
			?>
			<h5 class="vcard author">
				<a href="<?php echo esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ); ?>" class="fn">
					<?php the_author_meta( 'display_name' ); ?>
				</a>
			</h5>
			<p><?php the_author_meta( 'description' ); ?></p>
			<?php
			if ( startup_get_settings( 'authorbox_social_share' ) ) {
				$userid    = get_current_user_id();
				$facebook  = get_the_author_meta( 'facebook', $userid );
				$twitter   = get_the_author_meta( 'twitter', $userid );
				$instagram = get_the_author_meta( 'instagram', $userid );
				$pinterest = get_the_author_meta( 'pinterest', $userid );
				$linkedin  = get_the_author_meta( 'linkedin', $userid );

				if ( ! empty( $facebook ) || ! empty( $twitter ) || ! empty( $instagram ) || ! empty( $pinterest ) || ! empty( $linkedin ) ) {
					echo '<div class="author-social clearfix">';
					if ( ! empty( $facebook ) ) {
						echo '<a href="' . $facebook . '" class="facebook"><i class="fa fa-facebook"></i></a>';
					}
					if ( ! empty( $twitter ) ) {
						echo '<a href="' . $twitter . '" class="twitter"><i class="fa fa-twitter"></i></a>';
					}
					if ( ! empty( $instagram ) ) {
						echo '<a href="' . $instagram . '" class="instagram"><i class="fa fa-instagram"></i></a>';
					}
					if ( ! empty( $pinterest ) ) {
						echo '<a href="' . $pinterest . '" class="pinterest"><i class="fa fa-pinterest"></i></a>';
					}
					if ( ! empty( $linkedin ) ) {
						echo '<a href="' . $linkedin . '" class="linkedin"><i class="fa fa-linkedin"></i></a>';
					}
					echo '</div>';
				}
			}
			?>
		</div>
	<?php
	}

	public function single_subscribe_box() {
		if ( is_active_sidebar( 'single-subscribe' ) ) {
		?>
			<div class="single-subscribe clear">
				<?php dynamic_sidebar( 'single-subscribe' ); ?>
			</div>
		<?php
		}
	}

	public function single_post_ads( $location ) {
		// Above Content Ad Code.
		if ( ! empty( startup_get_settings( 'mts_posttop_adcode' ) ) && 'above' == $location ) {
			$toptime = ! empty( startup_get_settings( 'mts_posttop_adcode_time' ) ) ? startup_get_settings( 'mts_posttop_adcode_time' ) : '0';
			if ( strcmp( date( 'Y-m-d', strtotime( -$toptime . ' day' ) ), get_the_time( 'Y-m-d' ) ) >= 0 ) {
				?>
				<div class="topad">
					<?php echo do_shortcode( startup_get_settings( 'mts_posttop_adcode' ) ); ?>
				</div>
				<?php
			}
		}
		// Below Content Ad Code.
		if ( ! empty( startup_get_settings( 'mts_postend_adcode' ) ) && 'below' == $location ) {
			$endtime = ! empty( startup_get_settings( 'mts_postend_adcode_time' ) ) ? startup_get_settings( 'mts_postend_adcode_time' ) : '0';
			if ( strcmp( date( 'Y-m-d', strtotime( -$endtime . ' day' ) ), get_the_time( 'Y-m-d' ) ) >= 0 ) {
				?>
				<div class="bottomad">
					<?php echo do_shortcode( startup_get_settings( 'mts_postend_adcode' ) ); ?>
				</div>
				<?php
			}
		}
	}

	public function single_post_social_icons( $location ) {
		// Social Share icons above content.
		if ( null !== startup_get_settings( 'mts_social_button_position' ) && 'top' === startup_get_settings( 'mts_social_button_position' ) && 'above' == $location ) {
			startup_social_buttons();
		}
		// Social Share icons below content and floating.
		if ( ( null !== startup_get_settings( 'mts_social_button_position' ) ) && 'top' !== startup_get_settings( 'mts_social_button_position' ) && 'below' == $location ) {
			startup_social_buttons();
		}
	}

}
