<?php
/**
 * HomePage Pagination
 *
 * @package Startup
 */

$menus['blog']['child']['blog-pagination'] = array(
	'title' => esc_html__( 'Pagination', 'startup' ),
	'desc'  => esc_html__( 'From here, you can control the elements of pagination.', 'startup' ),
);

// Dependency check - Default and Numbered pagination.
$default_pagination_dependency = array(
	'relation' => 'and',
	array(
		'field'      => 'mts_pagenavigation_type',
		'value'      => '2',
		'comparison' => '!=',
	),
);

// Dependency check the load more button.
$loadmore_button_dependency = array(
	'relation' => 'and',
	array(
		'field'      => 'mts_pagenavigation_type',
		'value'      => '2',
		'comparison' => '==',
	),
);

$sections['blog-pagination'] = array(

	array(
		'id'       => 'mts_pagenavigation_type',
		'type'     => 'radio',
		'title'    => esc_html__( 'Pagination Type', 'startup' ),
		'sub_desc' => esc_html__( 'Select pagination type.', 'startup' ),
		'options'  => array(
			'0' => esc_html__( 'Default (Next / Previous)', 'startup' ),
			'1' => esc_html__( 'Numbered (1 2 3 4...)', 'startup' ),
			'2' => esc_html__( 'AJAX (Load More Button)', 'startup' ),
			'3' => esc_html__( 'AJAX (Auto Infinite Scroll)', 'startup' ),
		),
		'std'      => '1',
	),

	array(
		'id'         => 'pagenavigation_alignment',
		'type'       => 'button_set',
		'title'      => esc_html__( 'Pagination Alignment', 'startup' ),
		'sub_desc'   => esc_html__( 'Choose pagination alignment from here.', 'startup' ),
		'options'    => array(
			'left'   => esc_html__( 'Left', 'startup' ),
			'center' => esc_html__( 'Center', 'startup' ),
			'right'  => esc_html__( 'Right', 'startup' ),
		),
		'std'        => 'center',
		'dependency' => $default_pagination_dependency,
	),

	array(
		'id'         => 'load_more_alignment',
		'type'       => 'button_set',
		'title'      => esc_html__( 'Load More Alignment', 'startup' ),
		'sub_desc'   => esc_html__( 'Choose the load more alignment from here.', 'startup' ),
		'options'    => array(
			'left'   => esc_html__( 'Left', 'startup' ),
			'center' => esc_html__( 'Center', 'startup' ),
			'right'  => esc_html__( 'Right', 'startup' ),
			'full'   => esc_html__( 'Full Width', 'startup' ),
		),
		'std'        => 'center',
		'dependency' => $loadmore_button_dependency,
	),

	array(
		'id'         => 'mts_pagenavigation_bgcolor',
		'type'       => 'color',
		'title'      => esc_html__( 'Pagination background color', 'startup' ),
		'sub_desc'   => esc_html__( 'Select pagination background color.', 'startup' ),
		'std'        => '#ebecf0',
		'dependency' => $default_pagination_dependency,
	),
	array(
		'id'         => 'load_more_bgcolor',
		'type'       => 'color',
		'title'      => esc_html__( 'Load More background color', 'startup' ),
		'sub_desc'   => esc_html__( 'Select background color for load more button.', 'startup' ),
		'std'        => '#ebecf0',
		'dependency' => $loadmore_button_dependency,
	),
	array(
		'id'         => 'mts_pagenavigation_hover_bgcolor',
		'type'       => 'color',
		'title'      => esc_html__( 'Pagination background hover color', 'startup' ),
		'sub_desc'   => esc_html__( 'Select pagination background hover color.', 'startup' ),
		'std'        => startup_get_settings( 'primary_color_scheme' ),
		'dependency' => $default_pagination_dependency,
	),
	array(
		'id'         => 'load_more_hover_bgcolor',
		'type'       => 'color',
		'title'      => esc_html__( 'Load More background hover color', 'startup' ),
		'sub_desc'   => esc_html__( 'Select background hover color for load more button.', 'startup' ),
		'std'        => startup_get_settings( 'primary_color_scheme' ),
		'dependency' => $loadmore_button_dependency,
	),
	array(
		'id'         => 'mts_pagenavigation_color',
		'type'       => 'color',
		'title'      => esc_html__( 'Pagination color', 'startup' ),
		'sub_desc'   => esc_html__( 'Select pagination color.', 'startup' ),
		'std'        => '#253858',
		'dependency' => $default_pagination_dependency,
	),
	array(
		'id'         => 'load_more_color',
		'type'       => 'color',
		'title'      => esc_html__( 'Load More color', 'startup' ),
		'sub_desc'   => esc_html__( 'Select color for load more button.', 'startup' ),
		'std'        => '#253858',
		'dependency' => $loadmore_button_dependency,
	),
	array(
		'id'         => 'mts_pagenavigation_hover_color',
		'type'       => 'color',
		'title'      => esc_html__( 'Pagination hover color', 'startup' ),
		'sub_desc'   => esc_html__( 'Select pagination hover color.', 'startup' ),
		'std'        => '#ffffff',
		'dependency' => $default_pagination_dependency,
	),
	array(
		'id'         => 'load_more_hover_color',
		'type'       => 'color',
		'title'      => esc_html__( 'Load More hover color', 'startup' ),
		'sub_desc'   => esc_html__( 'Select hover color for load more button.', 'startup' ),
		'std'        => '#ffffff',
		'dependency' => $loadmore_button_dependency,
	),
	array(
		'id'         => 'mts_pagenavigation_margin',
		'type'       => 'margin',
		'title'      => esc_html__( 'Pagination Margin', 'startup' ),
		'sub_desc'   => esc_html__( 'Update pagination margin from here.', 'startup' ),
		'std'        => array(
			'top'    => '0',
			'right'  => '8px',
			'bottom' => '10px',
			'left'   => '0',
		),
		'dependency' => $default_pagination_dependency,
	),
	array(
		'id'         => 'mts_pagenavigation_padding',
		'type'       => 'margin',
		'title'      => esc_html__( 'Pagination Padding', 'startup' ),
		'sub_desc'   => esc_html__( 'Update pagination padding from here.', 'startup' ),
		'std'        => array(
			'top'    => '13px',
			'right'  => '12px',
			'bottom' => '0',
			'left'   => '12px',
		),
		'dependency' => $default_pagination_dependency,
	),
	array(
		'id'         => 'load_more_padding',
		'type'       => 'margin',
		'title'      => esc_html__( 'Load More Padding', 'startup' ),
		'sub_desc'   => esc_html__( 'Update padding for Load More button from here.', 'startup' ),
		'std'        => array(
			'top'    => '17px',
			'right'  => '50px',
			'bottom' => '17px',
			'left'   => '50px',
		),
		'dependency' => $loadmore_button_dependency,
	),

	array(
		'id'         => 'mts_pagenavigation_border_radius',
		'type'       => 'text',
		'class'      => 'small-text',
		'title'      => esc_html__( 'Pagination Border Radius', 'startup' ),
		'sub_desc'   => esc_html__( 'Update Pagination Border Radius in px.', 'startup' ),
		'std'        => '50',
		'args'       => array( 'type' => 'number' ),
		'dependency' => $default_pagination_dependency,
	),

	array(
		'id'         => 'mts_loadmore_border_radius',
		'type'       => 'text',
		'class'      => 'small-text',
		'title'      => esc_html__( 'Load More border Radius', 'startup' ),
		'sub_desc'   => esc_html__( 'Update Load More Border Radius in px.', 'startup' ),
		'std'        => '4',
		'args'       => array( 'type' => 'number' ),
		'dependency' => $loadmore_button_dependency,
	),

	array(
		'id'       => 'pagenavigation_border',
		'type'     => 'border',
		'title'    => esc_html__( 'Border', 'startup' ),
		'sub_desc' => esc_html__( 'Select border', 'startup' ),
	),
	array(
		'id'    => 'pagination_font',
		'type'  => 'typography',
		'title' => esc_html__( 'Pagination', 'startup' ),
		'color' => false,
		'std'   => array(
			'preview-text'  => 'Pagination',
			'preview-color' => 'light',
			'font-family'   => 'Montserrat',
			'font-weight'   => '500',
			'font-size'     => '14px',
			'css-selectors' => '.pagination, #load-posts a',
		),
	),

);
