<?php
/**
 * HomePage Posts
 *
 * @package Startup
 */

$features = startup_get_settings( 'mts_featured_categories' );
if ( empty( $features ) ) {
	return;
}
foreach ( $features as $feature ) :
	$title        = isset( $feature['mts_featured_title'] ) ? $feature['mts_featured_title'] : 'No Title';
	$posts_layout = isset( $feature['blog_layout'] ) ? $feature['blog_layout'] : '';
	if ( 'layout-default' === $posts_layout ) {
		$posts_layout = 'default';
	}
	$unique_id = isset( $feature['unique_id'] ) ? $feature['unique_id'] : '';

	$menus['blog']['child'][ 'blog-' . $unique_id ] = array(
		'title' => $title,
		// translators: description.
		'desc'  => sprintf( wp_kses_post( __( 'From here, you can control the elements of %s', 'startup' ) ), $title ),
	);

	// Dependency check that back to top option is enable.
	$post_title_dependency = array(
		'relation' => 'and',
		array(
			'field'      => 'mts_featured_category_title_' . $unique_id,
			'value'      => '1',
			'comparison' => '==',
		),
	);

	// Dependency check - Read More
	$readmore = array(
		'relation' => 'and',
		array(
			'field'      => 'readmore_' . $unique_id,
			'value'      => '1',
			'comparison' => '==',
		),
	);

	$sections[ 'blog-' . $unique_id ] = array(

		/**
		 * Layout Default Settings
		 *
		 * @package Startup
		 */

		// Section Title.
		( 'default' === $posts_layout ) ? array(
			'id'    => 'mts_post_title_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Section Title', 'startup' ),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'       => 'mts_featured_category_title_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Show/Hide Title', 'startup' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide title of post container.', 'startup' ),
			'std'      => '0',
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'         => 'mts_post_title_alignment_' . $unique_id,
			'type'       => 'button_set',
			'title'      => esc_html__( 'Section Title Alignment', 'startup' ),
			'sub_desc'   => esc_html__( 'Choose the section title alignment', 'startup' ),
			'options'    => array(
				'left'   => esc_html__( 'Left', 'startup' ),
				'center' => esc_html__( 'Center', 'startup' ),
				'right'  => esc_html__( 'Right', 'startup' ),
			),
			'std'        => 'left',
			'dependency' => $post_title_dependency,
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'         => 'mts_featured_category_title_background_' . $unique_id,
			'type'       => 'background',
			'title'      => esc_html__( 'Post Title Background Color', 'startup' ),
			'sub_desc'   => esc_html__( 'Set background color, pattern and image from here.', 'startup' ),
			'options'    => array(
				'color'         => '',            // false to disable, not needed otherwise.
				'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
				'image_upload'  => '',            // false to disable, not needed otherwise.
				'repeat'        => array(),       // false to disable, array of options to override default ( optional ).
				'attachment'    => array(),       // false to disable, array of options to override default ( optional ).
				'position'      => array(),       // false to disable, array of options to override default ( optional ).
				'size'          => array(),       // false to disable, array of options to override default ( optional ).
				'gradient'      => '',            // false to disable, not needed otherwise.
				'parallax'      => array(),       // false to disable, array of options to override default ( optional ).
			),
			'std'        => array(
				'color'         => '',
				'use'           => 'pattern',
				'image_pattern' => 'nobg',
				'image_upload'  => '',
				'repeat'        => 'repeat',
				'attachment'    => 'scroll',
				'position'      => 'left top',
				'size'          => 'cover',
				'gradient'      => array(
					'from'      => '#ffffff',
					'to'        => '#000000',
					'direction' => '0deg',
				),
				'parallax'      => '0',
			),
			'dependency' => $post_title_dependency,
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'         => 'mts_featured_category_title_margin_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Post Title Margin', 'startup' ),
			'sub_desc'   => esc_html__( 'Set section title margin from here.', 'startup' ),
			'std'        => array(
				'top'    => '0',
				'right'  => '0',
				'bottom' => '40px',
				'left'   => '0',
			),
			'dependency' => $post_title_dependency,
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'         => 'mts_featured_category_title_padding_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Post Title Padding', 'startup' ),
			'sub_desc'   => esc_html__( 'Set section title padding from here.', 'startup' ),
			'std'        => array(
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
				'left'   => '0',
			),
			'dependency' => $post_title_dependency,
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'         => 'post_title_border_' . $unique_id,
			'type'       => 'border',
			'title'      => esc_html__( 'Border', 'startup' ),
			'sub_desc'   => esc_html__( 'Select border', 'startup' ),
			'dependency' => $post_title_dependency,
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'         => 'mts_featured_category_title_font_' . $unique_id,
			'type'       => 'typography',
			'title'      => esc_html__( 'Section Title Typography', 'startup' ),
			'std'        => array(
				'preview-text'  => 'Title Font',
				'preview-color' => 'light',
				'font-family'   => 'Montserrat',
				'font-weight'   => '700',
				'font-size'     => '30px',
				'color'         => '#091e42',
				'line-height'   => '1.5',
				'css-selectors' => '.title-container.title-id-' . $unique_id . ' h3.featured-category-title',
			),
			'dependency' => $post_title_dependency,
		) : null,

		// Meta info.
		( 'default' === $posts_layout ) ? array(
			'id'    => 'post_meta_info_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Meta Info', 'startup' ),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'       => 'mts_home_headline_meta_info' . $unique_id,
			'type'     => 'layout2',
			// translators: title.
			'title'    => sprintf( wp_kses_post( __( '%s Meta Info', 'startup' ) ), $title ),
			// translators: description.
			'sub_desc' => sprintf( wp_kses_post( __( 'Organize how you want the post meta info to appear on %s', 'startup' ) ), $title ),
			'options'  => array(
				'enabled'  => array(
					'author'   => array(
						'label'     => __( 'Author Name', 'startup' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_author_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'startup' ),
								'std'   => 'user-o',
							),
						),
					),
					'date'     => array(
						'label'     => esc_html__( 'Date', 'startup' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_date_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'startup' ),
								'std'   => 'calendar',
							),
						),
					),
					'category' => array(
						'label'     => esc_html__( 'Categories', 'startup' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_category_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'startup' ),
								'std'   => 'folder-o',
							),
						),
					),
				),
				'disabled' => array(
					'comment' => array(
						'label'     => esc_html__( 'Comment Count', 'startup' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_comment_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'startup' ),
								'std'   => 'comment-o',
							),
						),
					),
				),
			),
			'std'      => array(
				'enabled'  => array(
					'author'   => array(
						'label'     => __( 'Author Name', 'startup' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_author_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'startup' ),
								'std'   => 'user-o',
							),
						),
					),
					'date'     => array(
						'label'     => esc_html__( 'Date', 'startup' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_date_icon_front_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'startup' ),
								'std'   => 'calendar',
							),
						),
					),
					'category' => array(
						'label'     => esc_html__( 'Categories', 'startup' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_category_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'startup' ),
								'std'   => 'folder-o',
							),
						),
					),
				),
				'disabled' => array(
					'comment' => array(
						'label'     => esc_html__( 'Comment Count', 'startup' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_comment_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'startup' ),
								'std'   => 'comment-o',
							),
						),
					),
				),
			),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'       => 'home_meta_info_bg_' . $unique_id,
			'type'     => 'color',
			'title'    => esc_html__( 'Home Meta Info Background Color', 'startup' ),
			'sub_desc' => esc_html__( 'Set homepage meta info background.', 'startup' ),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'       => 'mts_meta_info_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Margin', 'startup' ),
			'sub_desc' => esc_html__( 'Post Meta Info margin.', 'startup' ),
			'std'      => array(
				'top'    => '0',
				'right'  => '0',
				'bottom' => '28px',
				'left'   => '0',
			),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'       => 'mts_meta_info_padding_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Padding', 'startup' ),
			'sub_desc' => esc_html__( 'Post Meta Info padding.', 'startup' ),
			'std'      => array(
				'top'    => '0',
				'right'  => '9px',
				'bottom' => '0',
				'left'   => '0',
			),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'       => 'meta_info_border_' . $unique_id,
			'type'     => 'border',
			'title'    => esc_html__( 'Border', 'startup' ),
			'sub_desc' => esc_html__( 'Select border.', 'startup' ),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'    => 'meta_info_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Meta Info Typography', 'startup' ),
			'std'   => array(
				'preview-text'   => 'Post Meta Info Font',
				'preview-color'  => 'light',
				'font-family'    => 'Montserrat',
				'font-weight'    => '500',
				'font-size'      => '12px',
				'color'          => '#7a869a',
				'additional-css' => 'text-transform: uppercase;',
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost .post-info, .layout-' . $unique_id . ' .latestPost .post-info span a',
			),
		) : null,

		// Read More
		( 'default' === $posts_layout ) ? array(
			'id'    => 'mts_readmore_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Read More Button', 'startup' ),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'       => 'readmore_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Enable/Disable Read More', 'startup' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide Read More.', 'startup' ),
			'std'      => '1',
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'         => 'readmore_padding_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Button Padding', 'startup' ),
			'sub_desc'   => esc_html__( 'Set Read More padding from here.', 'startup' ),
			'std'        => array(
				'top'    => '0px',
				'right'  => '0px',
				'bottom' => '0px',
				'left'   => '0px',
			),
			'dependency' => $readmore,
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'         => 'readmore_margin_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Button Margin', 'startup' ),
			'sub_desc'   => esc_html__( 'Set Read More margin from here.', 'startup' ),
			'std'        => array(
				'top'    => '30px',
				'right'  => '0px',
				'bottom' => '0px',
				'left'   => '0px',
			),
			'dependency' => $readmore,
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'         => 'readmore_color_' . $unique_id,
			'type'       => 'color',
			'title'      => esc_html__( 'Button Color', 'startup' ),
			'sub_desc'   => esc_html__( 'Set Read More button color from here.', 'startup' ),
			'std'        => '#637bfd',
			'dependency' => $readmore,
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'         => 'readmore_bg_' . $unique_id,
			'type'       => 'background',
			'title'      => esc_html__( 'Button Background', 'startup' ),
			'sub_desc'   => esc_html__( 'Set Read More background color, pattern and image from here.', 'startup' ),
			'options'    => array(
				'color'         => '',            // false to disable, not needed otherwise.
				'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
				'image_upload'  => '',            // false to disable, not needed otherwise.
				'repeat'        => array(),       // false to disable, array of options to override default ( optional ).
				'attachment'    => array(),       // false to disable, array of options to override default ( optional ).
				'position'      => array(),       // false to disable, array of options to override default ( optional ).
				'size'          => array(),       // false to disable, array of options to override default ( optional ).
				'gradient'      => '',            // false to disable, not needed otherwise.
				'parallax'      => array(),       // false to disable, array of options to override default ( optional ).
			),
			'std'        => array(
				'color'         => '',
				'use'           => 'pattern',
				'image_pattern' => 'nobg',
				'image_upload'  => '',
				'repeat'        => 'repeat',
				'attachment'    => 'scroll',
				'position'      => '',
				'size'          => 'cover',
				'gradient'      => array(
					'from'      => '#ffffff',
					'to'        => '#000000',
					'direction' => '0deg',
				),
				'parallax'      => '0',
			),
			'dependency' => $readmore,
		) : null,

		// Post Container.
		( 'default' === $posts_layout ) ? array(
			'id'    => 'mts_post_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Container', 'startup' ),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'       => 'mts_featured_category_background_' . $unique_id,
			'type'     => 'background',
			'title'    => esc_html__( 'Post Background Color', 'startup' ),
			'sub_desc' => esc_html__( 'Set background color, pattern and image from here.', 'startup' ),
			'options'  => array(
				'color'         => '',            // false to disable, not needed otherwise.
				'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
				'image_upload'  => '',            // false to disable, not needed otherwise.
				'repeat'        => array(),       // false to disable, array of options to override default ( optional ).
				'attachment'    => array(),       // false to disable, array of options to override default ( optional ).
				'position'      => array(),       // false to disable, array of options to override default ( optional ).
				'size'          => array(),       // false to disable, array of options to override default ( optional ).
				'gradient'      => '',            // false to disable, not needed otherwise.
				'parallax'      => array(),       // false to disable, array of options to override default ( optional ).
			),
			'std'      => array(
				'color'         => '#f4f8ff',
				'use'           => 'pattern',
				'image_pattern' => 'nobg',
				'image_upload'  => '',
				'repeat'        => 'repeat',
				'attachment'    => 'scroll',
				'position'      => 'left top',
				'size'          => 'cover',
				'gradient'      => array(
					'from'      => '#ffffff',
					'to'        => '#000000',
					'direction' => '0deg',
				),
				'parallax'      => '0',
			),
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'       => 'post_border_' . $unique_id,
			'type'     => 'border',
			'title'    => esc_html__( 'Border', 'startup' ),
			'sub_desc' => esc_html__( 'Select border', 'startup' ),
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'       => 'post_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Margin', 'startup' ),
			'sub_desc' => esc_html__( 'Post margin.', 'startup' ),
			'left'     => false,
			'right'    => false,
			'std'      => array(
				'top'    => '0',
				'bottom' => '0',
			),
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'       => 'post_padding_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Padding', 'startup' ),
			'sub_desc' => esc_html__( 'Post padding.', 'startup' ),
			'std'      => array(
				'left'   => '0',
				'top'    => '40px',
				'right'  => '0',
				'bottom' => '40px',
			),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'    => 'post_title_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Title Font', 'startup' ),
			'std'   => array(
				'preview-text'  => 'Post Title Font',
				'preview-color' => 'light',
				'font-family'   => 'Montserrat',
				'font-weight'   => '700',
				'font-size'     => '24px',
				'line-height'   => '1.4',
				'color'         => '#505f79',
				'css-selectors' => '.layout-' . $unique_id . ' .latestPost .title a',
			),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'    => 'post_excerpt_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Excerpt Font', 'startup' ),
			'std'   => array(
				'preview-text'  => 'Post Excerpt Font',
				'preview-color' => 'light',
				'font-family'   => 'Montserrat',
				'font-weight'   => '400',
				'font-size'     => '14px',
				'line-height'   => '25px',
				'color'         => '#505f79',
				'css-selectors' => '.layout-' . $unique_id . ' .latestPost .front-view-content',
			),
		) : null,

		/**
		 * Layout Featured Settings
		 *
		 * @package Startup
		 */

		// Section Title.
		( 'layout-grid' === $posts_layout ) ? array(
			'id'    => 'mts_post_title_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Section Title', 'startup' ),
		) : null,

		( 'layout-grid' === $posts_layout ) ? array(
			'id'       => 'mts_featured_category_title_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Show/Hide Title', 'startup' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide title of post container.', 'startup' ),
			'std'      => '1',
		) : null,

		( 'layout-grid' === $posts_layout ) ? array(
			'id'         => 'mts_post_title_alignment_' . $unique_id,
			'type'       => 'button_set',
			'title'      => esc_html__( 'Section Title Alignment', 'startup' ),
			'sub_desc'   => esc_html__( 'Choose the section title alignment', 'startup' ),
			'options'    => array(
				'left'   => esc_html__( 'Left', 'startup' ),
				'center' => esc_html__( 'Center', 'startup' ),
				'right'  => esc_html__( 'Right', 'startup' ),
			),
			'std'        => 'left',
			'dependency' => $post_title_dependency,
		) : null,
		( 'layout-grid' === $posts_layout ) ? array(
			'id'         => 'mts_featured_category_title_background_' . $unique_id,
			'type'       => 'background',
			'title'      => esc_html__( 'Post Title Background Color', 'startup' ),
			'sub_desc'   => esc_html__( 'Set background color, pattern and image from here.', 'startup' ),
			'options'    => array(
				'color'         => '',            // false to disable, not needed otherwise.
				'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
				'image_upload'  => '',            // false to disable, not needed otherwise.
				'repeat'        => array(),       // false to disable, array of options to override default ( optional ).
				'attachment'    => array(),       // false to disable, array of options to override default ( optional ).
				'position'      => array(),       // false to disable, array of options to override default ( optional ).
				'size'          => array(),       // false to disable, array of options to override default ( optional ).
				'gradient'      => '',            // false to disable, not needed otherwise.
				'parallax'      => array(),       // false to disable, array of options to override default ( optional ).
			),
			'std'        => array(
				'color'         => '',
				'use'           => 'pattern',
				'image_pattern' => 'nobg',
				'image_upload'  => '',
				'repeat'        => 'repeat',
				'attachment'    => 'scroll',
				'position'      => 'left top',
				'size'          => 'cover',
				'gradient'      => array(
					'from'      => '#ffffff',
					'to'        => '#000000',
					'direction' => '0deg',
				),
				'parallax'      => '0',
			),
			'dependency' => $post_title_dependency,
		) : null,
		( 'layout-grid' === $posts_layout ) ? array(
			'id'         => 'mts_featured_category_title_margin_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Post Title Margin', 'startup' ),
			'sub_desc'   => esc_html__( 'Set section title margin from here.', 'startup' ),
			'std'        => array(
				'top'    => '0',
				'right'  => '0',
				'bottom' => '21px',
				'left'   => '0',
			),
			'dependency' => $post_title_dependency,
		) : null,
		( 'layout-grid' === $posts_layout ) ? array(
			'id'         => 'mts_featured_category_title_padding_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Post Title Padding', 'startup' ),
			'sub_desc'   => esc_html__( 'Set section title padding from here.', 'startup' ),
			'std'        => array(
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
				'left'   => '0',
			),
			'dependency' => $post_title_dependency,
		) : null,
		( 'layout-grid' === $posts_layout ) ? array(
			'id'         => 'post_title_border_' . $unique_id,
			'type'       => 'border',
			'title'      => esc_html__( 'Border', 'startup' ),
			'sub_desc'   => esc_html__( 'Select border', 'startup' ),
			'dependency' => $post_title_dependency,
		) : null,

		( 'layout-grid' === $posts_layout ) ? array(
			'id'         => 'mts_featured_category_title_font_' . $unique_id,
			'type'       => 'typography',
			'title'      => esc_html__( 'Section Title Typography', 'startup' ),
			'std'        => array(
				'preview-text'  => 'Title Font',
				'preview-color' => 'light',
				'font-family'   => 'Montserrat',
				'font-weight'   => '700',
				'font-size'     => '30px',
				'line-height'   => '1.5',
				'color'         => '#091e42',
				'css-selectors' => '.title-container.title-id-' . $unique_id . ' h3.featured-category-title',
			),
			'dependency' => $post_title_dependency,
		) : null,

		// Meta info.
		( 'layout-grid' === $posts_layout ) ? array(
			'id'    => 'post_meta_info_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Meta Info', 'startup' ),
		) : null,

		( 'layout-grid' === $posts_layout ) ? array(
			'id'       => 'mts_home_headline_meta_info' . $unique_id,
			'type'     => 'layout2',
			// translators: title.
			'title'    => sprintf( wp_kses_post( __( '%s Meta Info', 'startup' ) ), $title ),
			// translators: description.
			'sub_desc' => sprintf( wp_kses_post( __( 'Organize how you want the post meta info to appear on %s', 'startup' ) ), $title ),
			'options'  => array(
				'enabled'  => array(
					'author'   => array(
						'label'     => __( 'Author Name', 'startup' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_author_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'startup' ),
							),
						),
					),
					'date'     => array(
						'label'     => esc_html__( 'Date', 'startup' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_date_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'startup' ),
							),
						),
					),
					'category' => array(
						'label'     => esc_html__( 'Categories', 'startup' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_category_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'startup' ),
							),
						),
					),
				),
				'disabled' => array(
					'comment' => array(
						'label'     => esc_html__( 'Comment Count', 'startup' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_comment_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'startup' ),
							),
						),
					),
				),
			),
			'std'      => array(
				'enabled'  => array(
					'author'  => array(
						'label'     => __( 'Author Name', 'startup' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_author_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'startup' ),
							),
						),
					),
					'comment' => array(
						'label'     => esc_html__( 'Comment Count', 'startup' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_comment_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'startup' ),
								'std'   => 'comment-o',
							),
						),
					),
				),
				'disabled' => array(
					'category' => array(
						'label'     => esc_html__( 'Categories', 'startup' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_category_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'startup' ),
							),
						),
					),
				),
			),
		) : null,

		( 'layout-grid' === $posts_layout ) ? array(
			'id'       => 'home_meta_info_bg_' . $unique_id,
			'type'     => 'color',
			'title'    => esc_html__( 'Home Meta Info Background Color', 'startup' ),
			'sub_desc' => esc_html__( 'Set homepage meta info background.', 'startup' ),
		) : null,

		( 'layout-grid' === $posts_layout ) ? array(
			'id'       => 'mts_meta_info_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Margin', 'startup' ),
			'sub_desc' => esc_html__( 'Post Meta Info margin.', 'startup' ),
			'std'      => array(
				'top'    => '14px',
				'right'  => '0',
				'bottom' => '5px',
				'left'   => '0',
			),
		) : null,
		( 'layout-grid' === $posts_layout ) ? array(
			'id'       => 'mts_meta_info_padding_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Padding', 'startup' ),
			'sub_desc' => esc_html__( 'Post Meta Info padding.', 'startup' ),
			'std'      => array(
				'top'    => '0',
				'right'  => '7px',
				'bottom' => '0',
				'left'   => '0',
			),
		) : null,

		( 'layout-grid' === $posts_layout ) ? array(
			'id'       => 'meta_info_border_' . $unique_id,
			'type'     => 'border',
			'title'    => esc_html__( 'Border', 'startup' ),
			'sub_desc' => esc_html__( 'Select border.', 'startup' ),
		) : null,

		( 'layout-grid' === $posts_layout ) ? array(
			'id'    => 'meta_info_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Meta Info Typography', 'startup' ),
			'std'   => array(
				'preview-text'  => 'Post Meta Info Font',
				'preview-color' => 'light',
				'font-family'   => 'Montserrat',
				'font-weight'   => '400',
				'font-size'     => '14px',
				'line-height'   => '1',
				'color'         => startup_get_settings( 'primary_color_scheme' ),
				'css-selectors' => '.layout-' . $unique_id . ' .latestPost .post-info, .layout-' . $unique_id . ' .latestPost .post-info span a',
			),
		) : null,

		// Read More
		( 'layout-grid' === $posts_layout ) ? array(
			'id'    => 'mts_readmore_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Read More Button', 'startup' ),
		) : null,

		( 'layout-grid' === $posts_layout ) ? array(
			'id'       => 'readmore_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Enable/Disable Read More', 'startup' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide Read More.', 'startup' ),
			'std'      => '1',
		) : null,

		( 'layout-grid' === $posts_layout ) ? array(
			'id'         => 'readmore_padding_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Button Padding', 'startup' ),
			'sub_desc'   => esc_html__( 'Set Read More padding from here.', 'startup' ),
			'std'        => array(
				'top'    => '0px',
				'right'  => '0px',
				'bottom' => '0px',
				'left'   => '0px',
			),
			'dependency' => $readmore,
		) : null,

		( 'layout-grid' === $posts_layout ) ? array(
			'id'         => 'readmore_margin_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Button Margin', 'startup' ),
			'sub_desc'   => esc_html__( 'Set Read More margin from here.', 'startup' ),
			'std'        => array(
				'top'    => '30px',
				'right'  => '0px',
				'bottom' => '0px',
				'left'   => '0px',
			),
			'dependency' => $readmore,
		) : null,

		( 'layout-grid' === $posts_layout ) ? array(
			'id'         => 'readmore_color_' . $unique_id,
			'type'       => 'color',
			'title'      => esc_html__( 'Button Color', 'startup' ),
			'sub_desc'   => esc_html__( 'Set Read More button color from here.', 'startup' ),
			'std'        => '#ffffff',
			'dependency' => $readmore,
		) : null,

		( 'layout-grid' === $posts_layout ) ? array(
			'id'         => 'readmore_bg_' . $unique_id,
			'type'       => 'background',
			'title'      => esc_html__( 'Button Background', 'startup' ),
			'sub_desc'   => esc_html__( 'Set Read More background color, pattern and image from here.', 'startup' ),
			'options'    => array(
				'color'         => '',            // false to disable, not needed otherwise.
				'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
				'image_upload'  => '',            // false to disable, not needed otherwise.
				'repeat'        => array(),       // false to disable, array of options to override default ( optional ).
				'attachment'    => array(),       // false to disable, array of options to override default ( optional ).
				'position'      => array(),       // false to disable, array of options to override default ( optional ).
				'size'          => array(),       // false to disable, array of options to override default ( optional ).
				'gradient'      => '',            // false to disable, not needed otherwise.
				'parallax'      => array(),       // false to disable, array of options to override default ( optional ).
			),
			'std'        => array(
				'color'         => '#00B8D9',
				'use'           => 'gradient',
				'image_pattern' => 'nobg',
				'image_upload'  => '',
				'repeat'        => 'repeat',
				'attachment'    => 'scroll',
				'position'      => '',
				'size'          => 'cover',
				'gradient'      => array(
					'from'      => '#00B8D9',
					'to'        => '#79E2F2',
					'direction' => '-82.012deg',
				),
				'parallax'      => '0',
			),
			'dependency' => $readmore,
		) : null,

		// Post Container.
		( 'layout-grid' === $posts_layout ) ? array(
			'id'    => 'mts_post_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Container', 'startup' ),
		) : null,

		( 'layout-grid' === $posts_layout ) ? array(
			'id'       => 'mts_featured_category_background_' . $unique_id,
			'type'     => 'background',
			'title'    => esc_html__( 'Post Background Color', 'startup' ),
			'sub_desc' => esc_html__( 'Set background color, pattern and image from here.', 'startup' ),
			'options'  => array(
				'color'         => '',            // false to disable, not needed otherwise.
				'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
				'image_upload'  => '',            // false to disable, not needed otherwise.
				'repeat'        => array(),       // false to disable, array of options to override default ( optional ).
				'attachment'    => array(),       // false to disable, array of options to override default ( optional ).
				'position'      => array(),       // false to disable, array of options to override default ( optional ).
				'size'          => array(),       // false to disable, array of options to override default ( optional ).
				'gradient'      => '',            // false to disable, not needed otherwise.
				'parallax'      => array(),       // false to disable, array of options to override default ( optional ).
			),
			'std'      => array(
				'color'         => '',
				'use'           => 'pattern',
				'image_pattern' => 'nobg',
				'image_upload'  => '',
				'repeat'        => 'repeat',
				'attachment'    => 'scroll',
				'position'      => 'left top',
				'size'          => 'cover',
				'gradient'      => array(
					'from'      => '#ffffff',
					'to'        => '#000000',
					'direction' => '0deg',
				),
				'parallax'      => '0',
			),
		) : null,
		( 'layout-grid' === $posts_layout ) ? array(
			'id'       => 'post_border_' . $unique_id,
			'type'     => 'border',
			'title'    => esc_html__( 'Border', 'startup' ),
			'sub_desc' => esc_html__( 'Select border', 'startup' ),
		) : null,
		( 'layout-grid' === $posts_layout ) ? array(
			'id'       => 'post_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Margin', 'startup' ),
			'sub_desc' => esc_html__( 'Post margin.', 'startup' ),
			'left'     => false,
			'right'    => false,
			'std'      => array(
				'top'    => '0',
				'bottom' => '0',
			),
		) : null,
		( 'layout-grid' === $posts_layout ) ? array(
			'id'       => 'post_padding_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Padding', 'startup' ),
			'sub_desc' => esc_html__( 'Post padding.', 'startup' ),
			'std'      => array(
				'left'   => '0',
				'top'    => '40px',
				'right'  => '0',
				'bottom' => '40px',
			),
		) : null,

		( 'layout-grid' === $posts_layout ) ? array(
			'id'    => 'post_title_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Title Font', 'startup' ),
			'std'   => array(
				'preview-text'  => 'Post Title Font',
				'preview-color' => 'light',
				'font-family'   => 'Montserrat',
				'font-weight'   => '700',
				'color'         => '#091e42',
				'font-size'     => '16px',
				'line-height'   => '1.5',
				'css-selectors' => '.layout-' . $unique_id . ' .latestPost .title a',
			),
		) : null,

		( 'layout-grid' === $posts_layout ) ? array(
			'id'    => 'post_excerpt_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Excerpt Font', 'startup' ),
			'std'   => array(
				'preview-text'  => 'Post Excerpt Font',
				'preview-color' => 'light',
				'font-family'   => 'Montserrat',
				'font-weight'   => '400',
				'font-size'     => '14px',
				'line-height'   => '25px',
				'color'         => '#505f79',
				'css-selectors' => '.layout-' . $unique_id . ' .latestPost .front-view-content',
			),
		) : null,

	);
endforeach;
