<?php
/**
 * HomePage Posts
 *
 * @package Startup
 */

$features = startup_get_settings( 'homepage_layout' );
if ( empty( $features ) ) {
	return;
}
foreach ( $features as $feature ) :
	$title        = isset( $feature['mts_home_title'] ) ? $feature['mts_home_title'] : 'No Title';
	$posts_layout = isset( $feature['home_layout'] ) ? $feature['home_layout'] : '';
	$unique_id    = isset( $feature['home_unique_id'] ) ? $feature['home_unique_id'] : '';

	$menus[ 'home-' . $unique_id ] = array(
		'title' => $title,
		// translators: description.
		'desc'  => sprintf( wp_kses_post( __( 'From here, you can control the elements of %s', 'blocks' ) ), $title ),
	);

	// Dependency check - 2 Column Features
	$twofeatures_button = array(
		'relation' => 'and',
		array(
			'field'      => 'twofeatures_button_' . $unique_id,
			'value'      => '1',
			'comparison' => '==',
		),
	);

	// Dependency check - 4 Column Features
	$fourfeatures_button = array(
		'relation' => 'and',
		array(
			'field'      => 'fourfeatures_button_' . $unique_id,
			'value'      => '1',
			'comparison' => '==',
		),
	);

	// Dependency check - CTA
	$cta_button = array(
		'relation' => 'and',
		array(
			'field'      => 'cta_button_' . $unique_id,
			'value'      => '1',
			'comparison' => '==',
		),
	);

	$pricing_list = join(
		PHP_EOL,
		[
			'8 GB RAM',
			'4 Core / 8 Thread',
			'Intel Xeon-D CPU',
			'1TB SSD Storage',
			'Unlimited 1Gbps Bandwidth',

			'Host 1 Domain',
			'24X7 Support',
			'Unlimited App\'s',
			'Free SSL Certificates',
		]
	);

	$sections[ 'home-' . $unique_id ] = array(

		/**
		 * Homepage Section - 3 Column Features
		 *
		 * @package Startup
		 */

		( 'three-column-features' === $posts_layout ) ? array(
			'id'        => 'home_threefeatures_' . $unique_id,
			'type'      => 'group',
			'title'     => esc_html__( '3 Column Features', 'startup' ),
			'sub_desc'  => esc_html__( 'Add features item appearing on the homepage 3 Column Features section.', 'startup' ),
			'groupname' => esc_html__( 'Features', 'startup' ),
			'subfields' => array(
				array(
					'id'    => 'threefeatures_icon_' . $unique_id,
					'type'  => 'icon_select',
					'title' => esc_html__( 'Icon', 'startup' ),
				),
				array(
					'id'       => 'threefeatures_icon_color_' . $unique_id,
					'type'     => 'color',
					'title'    => esc_html__( 'Select icon color', 'startup' ),
					'sub_desc' => esc_html__( 'The icon color will also be shown as hover state background color on features item.', 'startup' ),
					'std'      => '#637bfd',
				),
				array(
					'id'    => 'threefeatures_title_' . $unique_id,
					'type'  => 'text',
					'title' => esc_html__( 'Title', 'startup' ),
				),
				array(
					'id'    => 'threefeatures_text_' . $unique_id,
					'type'  => 'textarea',
					'title' => esc_html__( 'Text', 'startup' ),
				),
				array(
					'id'    => 'threefeatures_link_text_' . $unique_id,
					'type'  => 'text',
					'title' => esc_html__( 'Link Text', 'startup' ),
				),
				array(
					'id'    => 'threefeatures_link_' . $unique_id,
					'type'  => 'text',
					'title' => esc_html__( 'URL', 'startup' ),
				),
			),
			'std'       => array(
				'1' => array(
					'group_sort'                        => '1',
					'threefeatures_icon_' . $unique_id  => 'eercast',
					'threefeatures_icon_color_' . $unique_id => '#637bfd',
					'threefeatures_title_' . $unique_id => 'Elementor Compatible',
					'threefeatures_text_' . $unique_id  => 'Design your website, just the way you want it',
					'threefeatures_link_text_' . $unique_id => 'View Plans',
					'threefeatures_link_' . $unique_id  => '#',
				),
				'2' => array(
					'group_sort'                        => '2',
					'threefeatures_icon_' . $unique_id  => 'free-code-camp',
					'threefeatures_icon_color_' . $unique_id => '#637bfd',
					'threefeatures_title_' . $unique_id => 'Lightning Fast',
					'threefeatures_text_' . $unique_id  => 'Make loading times a thing of the past.',
					'threefeatures_link_text_' . $unique_id => 'View Plans',
					'threefeatures_link_' . $unique_id  => '#',
				),
				'3' => array(
					'group_sort'                        => '3',
					'threefeatures_icon_' . $unique_id  => 'bolt',
					'threefeatures_icon_color_' . $unique_id => '#637bfd',
					'threefeatures_title_' . $unique_id => 'Fully Customizable',
					'threefeatures_text_' . $unique_id  => 'Tens of features to customize and optimize your website',
					'threefeatures_link_text_' . $unique_id => 'View Plans',
					'threefeatures_link_' . $unique_id  => '#',
				),
			),
		) : null,
		// Post Container.
		( 'three-column-features' === $posts_layout ) ? array(
			'id'    => 'mts_post_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Container', 'startup' ),
		) : null,

		( 'three-column-features' === $posts_layout ) ? array(
			'id'       => 'home_section_padding_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Padding', 'startup' ),
			'sub_desc' => esc_html__( 'Set 3 Column Features section padding from here.', 'startup' ),
			'std'      => array(
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
				'left'   => '0',
			),
		) : null,

		( 'three-column-features' === $posts_layout ) ? array(
			'id'       => 'threefeatures_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Margin', 'startup' ),
			'sub_desc' => esc_html__( 'Set 3 Column Features section container margin from here.', 'startup' ),
			'left'     => false,
			'right'    => false,
			'std'      => array(
				'top'    => '-100px',
				'bottom' => '0',
			),
		) : null,

		( 'three-column-features' === $posts_layout ) ? array(
			'id'       => 'home_section_background_' . $unique_id,
			'type'     => 'background',
			'title'    => esc_html__( '3 Column Features Background', 'startup' ),
			'sub_desc' => esc_html__( 'Set background color, pattern and image from here.', 'startup' ),
			'options'  => array(
				'color'         => '',            // false to disable, not needed otherwise.
				'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
				'image_upload'  => '',            // false to disable, not needed otherwise.
				'repeat'        => array(),       // false to disable, array of options to override default ( optional ).
				'attachment'    => array(),       // false to disable, array of options to override default ( optional ).
				'position'      => array(),       // false to disable, array of options to override default ( optional ).
				'size'          => array(),       // false to disable, array of options to override default ( optional ).
				'gradient'      => '',            // false to disable, not needed otherwise.
				'parallax'      => array(),       // false to disable, array of options to override default ( optional ).
			),
			'std'      => array(
				'color'         => '#fafcff',
				'use'           => 'pattern',
				'image_pattern' => 'nobg',
				'image_upload'  => '',
				'repeat'        => 'no-repeat',
				'attachment'    => 'scroll',
				'position'      => 'left top',
				'size'          => 'cover',
				'gradient'      => array(
					'from'      => '#ffffff',
					'to'        => '#000000',
					'direction' => '0deg',
				),
				'parallax'      => '0',
			),
		) : null,

		( 'three-column-features' === $posts_layout ) ? array(
			'id'       => 'threefeatures_box_shadow_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Show Box Shadow', 'startup' ),
			'sub_desc' => esc_html__( 'Enable/Disable the box shadow in 3 Column Features', 'startup' ),
			'std'      => '1',
		) : null,

		( 'three-column-features' === $posts_layout ) ? array(
			'id'       => 'threefeatures_border_radius_' . $unique_id,
			'type'     => 'text',
			'class'    => 'small-text',
			'title'    => esc_html__( '3 Column Features Border Radius', 'startup' ),
			'sub_desc' => esc_html__( 'Update 3 Column Features border radius in px.', 'startup' ),
			'std'      => '4',
			'args'     => array( 'type' => 'number' ),
		) : null,

		( 'three-column-features' === $posts_layout ) ? array(
			'id'    => 'threefeatures_title_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Title Font', 'startup' ),
			'std'   => array(
				'preview-text'  => 'Title',
				'preview-color' => 'light',
				'font-family'   => 'Montserrat',
				'font-weight'   => '500',
				'color'         => '#091e42',
				'font-size'     => '20px',
				'line-height'   => '1.2',
				'css-selectors' => '.layout-' . $unique_id . '.threefeatures-section h3',
			),
		) : null,

		( 'three-column-features' === $posts_layout ) ? array(
			'id'    => 'threefeatures_text_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Text Font', 'startup' ),
			'std'   => array(
				'preview-text'  => 'Text',
				'preview-color' => 'light',
				'font-family'   => 'Montserrat',
				'font-weight'   => '400',
				'color'         => '#505f79',
				'font-size'     => '14px',
				'line-height'   => '25px',
				'css-selectors' => '.layout-' . $unique_id . '.threefeatures-section p.text',
			),
		) : null,

		/**
		 * Homepage Section - 2 Column Features
		 *
		 * @package Startup
		 */

		( 'two-column-features' === $posts_layout ) ? array(
			'id'       => 'twofeatures_heading_' . $unique_id,
			'type'     => 'text',
			'title'    => esc_html__( 'Heading', 'startup' ),
			'sub_desc' => esc_html__( 'Enter heading from here', 'startup' ),
			'std'      => 'A theme like no other theme',
		) : null,

		( 'two-column-features' === $posts_layout ) ? array(
			'id'       => 'twofeatures_subheading_' . $unique_id,
			'type'     => 'textarea',
			'title'    => esc_html__( 'Subheading', 'startup' ),
			'sub_desc' => esc_html__( 'Enter subheading from here', 'startup' ),
			'std'      => 'Startup is uniquely designed to be the perfect theme not only for startup but also for blogs and website that cover startup.',
		) : null,

		( 'two-column-features' === $posts_layout ) ? array(
			'id'       => 'twofeatures_image_' . $unique_id,
			'type'     => 'upload',
			'title'    => esc_html__( 'Upload Image', 'startup' ),
			'sub_desc' => wp_kses( __( 'Upload Two Features Image from here <strong>Recommend Size 670x470px</strong>', 'startup' ), array( 'strong' => array() ) ),
			'return'   => 'url',
			'std'      => get_template_directory_uri() . '/images/highly-secure&reliable.png',
		) : null,

		( 'two-column-features' === $posts_layout ) ? array(
			'id'       => 'twofeatures_content_position_' . $unique_id,
			'type'     => 'button_set',
			'title'    => esc_html__( 'Content Position', 'startup' ),
			'options'  => array(
				'right' => esc_html__( 'Right Side', 'startup' ),
				'left'  => esc_html__( 'Left Side', 'startup' ),
			),
			'sub_desc' => esc_html__( 'Choose content position for 2 Column Features section. If the content is set to right side the image will be shown on left side and vice versa.', 'startup' ),
			'std'      => 'right',
			'class'    => 'green',
		) : null,

		( 'two-column-features' === $posts_layout ) ? array(
			'id'         => 'twofeatures_image_position_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Image Position', 'startup' ),
			'sub_desc'   => esc_html__( 'Set Image position for 2 Column Features section. It will be shown when image is set to right and content is set to left side.', 'startup' ),
			'std'        => array(
				'top'    => '0px',
				'right'  => '60px',
				'bottom' => 'auto',
				'left'   => 'auto',
			),
			'dependency' => array(
				'relation' => 'and',
				array(
					'field'      => 'twofeatures_content_position_' . $unique_id,
					'value'      => 'left',
					'comparison' => '==',
				),
			),
		) : null,

		( 'two-column-features' === $posts_layout ) ? array(
			'id'        => 'home_twofeatures_' . $unique_id,
			'type'      => 'group',
			'title'     => esc_html__( '2 Column Features', 'startup' ),
			'sub_desc'  => esc_html__( 'Add features item appearing on the homepage 2 Column Features section.', 'startup' ),
			'groupname' => esc_html__( 'Features', 'startup' ),
			'subfields' => array(
				array(
					'id'    => 'twofeatures_icon_' . $unique_id,
					'type'  => 'icon_select',
					'title' => esc_html__( 'Icon', 'startup' ),
				),
				array(
					'id'       => 'twofeatures_icon_bg_' . $unique_id,
					'type'     => 'color',
					'title'    => esc_html__( 'Select icon background color', 'startup' ),
					'sub_desc' => esc_html__( 'The icon color will also be shown as hover state background color on features item.', 'startup' ),
					'std'      => '#637bfd',
				),
				array(
					'id'       => 'twofeatures_icon_color_' . $unique_id,
					'type'     => 'color',
					'title'    => esc_html__( 'Select icon color', 'startup' ),
					'sub_desc' => esc_html__( 'The icon color will also be shown as hover state background color on features item.', 'startup' ),
					'std'      => '#ffffff',
				),
				array(
					'id'    => 'twofeatures_title_' . $unique_id,
					'type'  => 'text',
					'title' => esc_html__( 'Title', 'startup' ),
				),
				array(
					'id'    => 'twofeatures_text_' . $unique_id,
					'type'  => 'textarea',
					'title' => esc_html__( 'Text', 'startup' ),
				),
			),
			'std'       => array(
				'1' => array(
					'group_sort'                           => '1',
					'twofeatures_icon_' . $unique_id       => 'universal-access',
					'twofeatures_icon_bg_' . $unique_id    => '#5160d5',
					'twofeatures_icon_color_' . $unique_id => '#ffffff',
					'twofeatures_title_' . $unique_id      => 'Modern Design',
					'twofeatures_text_' . $unique_id       => 'Startup features a modern, future-proof design that will stay beautiful for years to come.',
					'twofeatures_link_' . $unique_id       => '#',
				),
				'2' => array(
					'group_sort'                           => '2',
					'twofeatures_icon_' . $unique_id       => 'superpowers',
					'twofeatures_icon_bg_' . $unique_id    => '#5160d5',
					'twofeatures_icon_color_' . $unique_id => '#ffffff',
					'twofeatures_title_' . $unique_id      => 'Multiple Customization Options',
					'twofeatures_text_' . $unique_id       => 'Choose from multiple homepage designs, blog designs, and widgets to customize your website.',
					'twofeatures_link_' . $unique_id       => '#',
				),
				'3' => array(
					'group_sort'                           => '3',
					'twofeatures_icon_' . $unique_id       => 'exchange',
					'twofeatures_icon_bg_' . $unique_id    => '#5160d5',
					'twofeatures_icon_color_' . $unique_id => '#ffffff',
					'twofeatures_title_' . $unique_id      => 'Supreme Performance',
					'twofeatures_text_' . $unique_id       => 'Clean, optimized code, and dedicated performance options make for unmatched performance.',
					'twofeatures_link_' . $unique_id       => '#',
				),
			),
		) : null,

		( 'two-column-features' === $posts_layout ) ? array(
			'id'       => 'twofeatures_button_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Show Features Button', 'startup' ),
			'sub_desc' => wp_kses( __( 'Use this button to Show or Hide the <strong>Features</strong> button completely.', 'startup' ), array( 'strong' => '' ) ),
			'std'      => '1',
		) : null,

		( 'two-column-features' === $posts_layout ) ? array(
			'id'         => 'twofeatures_button_text_' . $unique_id,
			'type'       => 'text',
			'title'      => esc_html__( 'Button Text', 'startup' ),
			'sub_desc'   => esc_html__( 'Enter button text.', 'startup' ),
			'std'        => esc_html__( 'View Plans', 'startup' ),
			'dependency' => $twofeatures_button,
		) : null,

		( 'two-column-features' === $posts_layout ) ? array(
			'id'         => 'twofeatures_button_url_' . $unique_id,
			'type'       => 'text',
			'title'      => esc_html__( 'Button URL', 'startup' ),
			'sub_desc'   => esc_html__( 'Enter button URL.', 'startup' ),
			'std'        => '#',
			'dependency' => $twofeatures_button,
		) : null,

		( 'two-column-features' === $posts_layout ) ? array(
			'id'         => 'twofeatures_button_padding_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Button Padding', 'startup' ),
			'sub_desc'   => esc_html__( 'Set Button padding from here.', 'startup' ),
			'std'        => array(
				'top'    => '0px',
				'right'  => '0px',
				'bottom' => '0px',
				'left'   => '0px',
			),
			'dependency' => $twofeatures_button,
		) : null,

		( 'two-column-features' === $posts_layout ) ? array(
			'id'         => 'twofeatures_button_margin_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Button Margin', 'startup' ),
			'sub_desc'   => esc_html__( 'Set Button margin from here.', 'startup' ),
			'std'        => array(
				'top'    => '-20px',
				'right'  => '0px',
				'bottom' => '0px',
				'left'   => '70px',
			),
			'dependency' => $twofeatures_button,
		) : null,

		( 'two-column-features' === $posts_layout ) ? array(
			'id'         => 'twofeatures_button_color_' . $unique_id,
			'type'       => 'color',
			'title'      => esc_html__( 'Button Color', 'startup' ),
			'sub_desc'   => esc_html__( 'The icon color will also be shown as hover state background color on features item.', 'startup' ),
			'std'        => '#637bfd',
			'dependency' => $twofeatures_button,
		) : null,

		( 'two-column-features' === $posts_layout ) ? array(
			'id'         => 'twofeatures_button_bg_' . $unique_id,
			'type'       => 'background',
			'title'      => esc_html__( 'Button Background', 'startup' ),
			'sub_desc'   => esc_html__( 'Set buttons background color, pattern and image from here.', 'startup' ),
			'options'    => array(
				'color'         => '',            // false to disable, not needed otherwise.
				'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
				'image_upload'  => '',            // false to disable, not needed otherwise.
				'repeat'        => array(),       // false to disable, array of options to override default ( optional ).
				'attachment'    => array(),       // false to disable, array of options to override default ( optional ).
				'position'      => array(),       // false to disable, array of options to override default ( optional ).
				'size'          => array(),       // false to disable, array of options to override default ( optional ).
				'gradient'      => '',            // false to disable, not needed otherwise.
				'parallax'      => array(),       // false to disable, array of options to override default ( optional ).
			),
			'std'        => array(
				'color'         => '',
				'use'           => 'pattern',
				'image_pattern' => 'nobg',
				'image_upload'  => '',
				'repeat'        => 'repeat',
				'attachment'    => 'scroll',
				'position'      => '',
				'size'          => 'cover',
				'gradient'      => array(
					'from'      => '#ffffff',
					'to'        => '#000000',
					'direction' => '0deg',
				),
				'parallax'      => '0',
			),
			'dependency' => $twofeatures_button,
		) : null,

		( 'two-column-features' === $posts_layout ) ? array(
			'id'    => 'twofeatures_section_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( '2 Column Features General Stylings', 'startup' ),
		) : null,

		( 'two-column-features' === $posts_layout ) ? array(
			'id'       => 'home_section_padding_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Padding', 'startup' ),
			'sub_desc' => esc_html__( 'Set 2 Column Features section padding from here.', 'startup' ),
			'std'      => array(
				'top'    => '200px',
				'right'  => '0',
				'bottom' => '160px',
				'left'   => '0',
			),
		) : null,

		( 'two-column-features' === $posts_layout ) ? array(
			'id'       => 'home_section_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Margin', 'startup' ),
			'sub_desc' => esc_html__( 'Set 2 Column Features section margin from here.', 'startup' ),
			'std'      => array(
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
				'left'   => '0',
			),
		) : null,

		( 'two-column-features' === $posts_layout ) ? array(
			'id'       => 'home_section_background_' . $unique_id,
			'type'     => 'background',
			'title'    => esc_html__( '2 Column Features Background', 'startup' ),
			'sub_desc' => esc_html__( 'Set background color, pattern and image from here.', 'startup' ),
			'options'  => array(
				'color'         => '',            // false to disable, not needed otherwise.
				'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
				'image_upload'  => '',            // false to disable, not needed otherwise.
				'repeat'        => array(),       // false to disable, array of options to override default ( optional ).
				'attachment'    => array(),       // false to disable, array of options to override default ( optional ).
				'position'      => array(),       // false to disable, array of options to override default ( optional ).
				'size'          => array(),       // false to disable, array of options to override default ( optional ).
				'gradient'      => '',            // false to disable, not needed otherwise.
				'parallax'      => array(),       // false to disable, array of options to override default ( optional ).
			),
			'std'      => array(
				'color'         => '#f4f8ff',
				'use'           => 'pattern',
				'image_pattern' => 'nobg',
				'image_upload'  => '',
				'repeat'        => 'no-repeat',
				'attachment'    => 'scroll',
				'position'      => 'left top',
				'size'          => 'cover',
				'gradient'      => array(
					'from'      => '#ffffff',
					'to'        => '#000000',
					'direction' => '0deg',
				),
				'parallax'      => '0',
			),
		) : null,

		( 'two-column-features' === $posts_layout ) ? array(
			'id'    => 'twofeatures_heading_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Heading Font', 'startup' ),
			'std'   => array(
				'preview-text'  => 'Heading Font',
				'preview-color' => 'light',
				'font-family'   => 'Montserrat',
				'font-weight'   => '500',
				'color'         => '#091e42',
				'font-size'     => '27px',
				'line-height'   => '1.2',
				'css-selectors' => '.layout-' . $unique_id . '.twofeatures-section h2',
			),
		) : null,

		( 'two-column-features' === $posts_layout ) ? array(
			'id'    => 'twofeatures_subheading_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Subheading Font', 'startup' ),
			'std'   => array(
				'preview-text'  => 'Subheading Font',
				'preview-color' => 'light',
				'font-family'   => 'Montserrat',
				'font-weight'   => '400',
				'color'         => '#505f79',
				'font-size'     => '14px',
				'line-height'   => '25px',
				'css-selectors' => '.layout-' . $unique_id . '.twofeatures-section p.sub-heading',
			),
		) : null,

		( 'two-column-features' === $posts_layout ) ? array(
			'id'    => 'twofeatures_title_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Title Font', 'startup' ),
			'std'   => array(
				'preview-text'  => 'Title',
				'preview-color' => 'light',
				'font-family'   => 'Montserrat',
				'font-weight'   => '700',
				'font-size'     => '20px',
				'line-height'   => '1.2',
				'css-selectors' => '.layout-' . $unique_id . '.twofeatures-section h3',
			),
		) : null,

		( 'two-column-features' === $posts_layout ) ? array(
			'id'    => 'twofeatures_text_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Text Font', 'startup' ),
			'std'   => array(
				'preview-text'  => 'Text',
				'preview-color' => 'light',
				'font-family'   => 'Montserrat',
				'font-weight'   => '400',
				'color'         => '#505f79',
				'font-size'     => '14px',
				'line-height'   => '25px',
				'css-selectors' => '.layout-' . $unique_id . '.twofeatures-section p.text',
			),
		) : null,

		/**
		 * Homepage Section - 4 Column Features
		 *
		 * @package Startup
		 */

		( 'four-column-features' === $posts_layout ) ? array(
			'id'       => 'fourfeatures_heading_' . $unique_id,
			'type'     => 'text',
			'title'    => esc_html__( 'Heading', 'startup' ),
			'sub_desc' => esc_html__( 'Enter heading from here', 'startup' ),
			'std'      => 'Additional Theme Options',
		) : null,

		( 'four-column-features' === $posts_layout ) ? array(
			'id'       => 'fourfeatures_subheading_' . $unique_id,
			'type'     => 'textarea',
			'title'    => esc_html__( 'Subheading', 'startup' ),
			'sub_desc' => esc_html__( 'Enter subheading from here', 'startup' ),
			'std'      => 'The Startup Theme is packed with tons of features to create a functional, high converting website.',
		) : null,

		( 'four-column-features' === $posts_layout ) ? array(
			'id'        => 'home_fourfeatures_' . $unique_id,
			'type'      => 'group',
			'title'     => esc_html__( '4 Column Features', 'startup' ),
			'sub_desc'  => esc_html__( 'Add features item appearing on the homepage 2 Column Features section.', 'startup' ),
			'groupname' => esc_html__( 'Features', 'startup' ),
			'subfields' => array(
				array(
					'id'    => 'fourfeatures_icon_' . $unique_id,
					'type'  => 'icon_select',
					'title' => esc_html__( 'Icon', 'startup' ),
				),
				array(
					'id'       => 'fourfeatures_icon_bg_' . $unique_id,
					'type'     => 'color',
					'title'    => esc_html__( 'Select icon background color', 'startup' ),
					'sub_desc' => esc_html__( 'The icon color will also be shown as hover state background color on features item.', 'startup' ),
					'std'      => '#637bfd',
				),
				array(
					'id'       => 'fourfeatures_icon_color_' . $unique_id,
					'type'     => 'color',
					'title'    => esc_html__( 'Select icon color', 'startup' ),
					'sub_desc' => esc_html__( 'The icon color will also be shown as hover state background color on features item.', 'startup' ),
					'std'      => '#ffffff',
				),
				array(
					'id'    => 'fourfeatures_title_' . $unique_id,
					'type'  => 'text',
					'title' => esc_html__( 'Title', 'startup' ),
				),
				array(
					'id'    => 'fourfeatures_text_' . $unique_id,
					'type'  => 'textarea',
					'title' => esc_html__( 'Text', 'startup' ),
				),
			),
			'std'       => array(
				'1' => array(
					'group_sort'                         => '1',
					'fourfeatures_icon_' . $unique_id    => 'globe',
					'fourfeatures_icon_bg_' . $unique_id => '#637bfd',
					'fourfeatures_icon_color_' . $unique_id => '#ffffff',
					'fourfeatures_title_' . $unique_id   => 'SEO Optimizede',
					'fourfeatures_text_' . $unique_id    => 'Accelerate your website\'s growth with the powerful SEO features built right into the theme.',
					'fourfeatures_link_' . $unique_id    => '#',
				),
				'2' => array(
					'group_sort'                         => '2',
					'fourfeatures_icon_' . $unique_id    => 'braille',
					'fourfeatures_icon_bg_' . $unique_id => '#637bfd',
					'fourfeatures_icon_color_' . $unique_id => '#ffffff',
					'fourfeatures_title_' . $unique_id   => 'Schema Built-In',
					'fourfeatures_text_' . $unique_id    => 'Integrated Schema helps bring in more traffic with zero additional effort.',
					'fourfeatures_link_' . $unique_id    => '#',
				),
				'3' => array(
					'group_sort'                         => '3',
					'fourfeatures_icon_' . $unique_id    => 'thumbs-o-up',
					'fourfeatures_icon_bg_' . $unique_id => '#637bfd',
					'fourfeatures_icon_color_' . $unique_id => '#ffffff',
					'fourfeatures_title_' . $unique_id   => 'Adsense Optimized',
					'fourfeatures_text_' . $unique_id    => 'Optimized and flexible ad-placements help you bring in revenue from day one.',
					'fourfeatures_link_' . $unique_id    => '#',
				),
				'4' => array(
					'group_sort'                         => '4',
					'fourfeatures_icon_' . $unique_id    => 'star-o',
					'fourfeatures_icon_bg_' . $unique_id => '#637bfd',
					'fourfeatures_icon_color_' . $unique_id => '#ffffff',
					'fourfeatures_title_' . $unique_id   => 'Gutenberg Compatible',
					'fourfeatures_text_' . $unique_id    => 'Have the flexibility to create content with the classic, or the new Block editor.',
					'fourfeatures_link_' . $unique_id    => '#',
				),
			),
		) : null,

		( 'four-column-features' === $posts_layout ) ? array(
			'id'       => 'fourfeatures_button_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Show Features Button', 'startup' ),
			'sub_desc' => wp_kses( __( 'Use this button to Show or Hide the <strong>Features</strong> button completely.', 'startup' ), array( 'strong' => '' ) ),
			'std'      => '1',
		) : null,

		( 'four-column-features' === $posts_layout ) ? array(
			'id'         => 'fourfeatures_button_text_' . $unique_id,
			'type'       => 'text',
			'title'      => esc_html__( 'Button Text', 'startup' ),
			'sub_desc'   => esc_html__( 'Enter button text.', 'startup' ),
			'std'        => esc_html__( 'View Plans', 'startup' ),
			'dependency' => $fourfeatures_button,
		) : null,

		( 'four-column-features' === $posts_layout ) ? array(
			'id'         => 'fourfeatures_button_url_' . $unique_id,
			'type'       => 'text',
			'title'      => esc_html__( 'Button URL', 'startup' ),
			'sub_desc'   => esc_html__( 'Enter button URL.', 'startup' ),
			'std'        => '#',
			'dependency' => $fourfeatures_button,
		) : null,

		( 'four-column-features' === $posts_layout ) ? array(
			'id'         => 'fourfeatures_button_padding_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Button Padding', 'startup' ),
			'sub_desc'   => esc_html__( 'Set Button padding from here.', 'startup' ),
			'std'        => array(
				'top'    => '0px',
				'right'  => '0px',
				'bottom' => '0px',
				'left'   => '0px',
			),
			'dependency' => $fourfeatures_button,
		) : null,

		( 'four-column-features' === $posts_layout ) ? array(
			'id'         => 'fourfeatures_button_margin_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Button Margin', 'startup' ),
			'sub_desc'   => esc_html__( 'Set Button margin from here.', 'startup' ),
			'std'        => array(
				'top'    => '20px',
				'right'  => '0px',
				'bottom' => '0px',
				'left'   => '0px',
			),
			'dependency' => $fourfeatures_button,
		) : null,

		( 'four-column-features' === $posts_layout ) ? array(
			'id'         => 'fourfeatures_button_color_' . $unique_id,
			'type'       => 'color',
			'title'      => esc_html__( 'Button Color', 'startup' ),
			'sub_desc'   => esc_html__( 'The icon color will also be shown as hover state background color on features item.', 'startup' ),
			'std'        => '#637bfd',
			'dependency' => $fourfeatures_button,
		) : null,

		( 'four-column-features' === $posts_layout ) ? array(
			'id'         => 'fourfeatures_button_bg_' . $unique_id,
			'type'       => 'background',
			'title'      => esc_html__( 'Button Background', 'startup' ),
			'sub_desc'   => esc_html__( 'Set buttons background color, pattern and image from here.', 'startup' ),
			'options'    => array(
				'color'         => '',            // false to disable, not needed otherwise.
				'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
				'image_upload'  => '',            // false to disable, not needed otherwise.
				'repeat'        => array(),       // false to disable, array of options to override default ( optional ).
				'attachment'    => array(),       // false to disable, array of options to override default ( optional ).
				'position'      => array(),       // false to disable, array of options to override default ( optional ).
				'size'          => array(),       // false to disable, array of options to override default ( optional ).
				'gradient'      => '',            // false to disable, not needed otherwise.
				'parallax'      => array(),       // false to disable, array of options to override default ( optional ).
			),
			'std'        => array(
				'color'         => '',
				'use'           => 'pattern',
				'image_pattern' => 'nobg',
				'image_upload'  => '',
				'repeat'        => 'repeat',
				'attachment'    => 'scroll',
				'position'      => '',
				'size'          => 'cover',
				'gradient'      => array(
					'from'      => '#ffffff',
					'to'        => '#000000',
					'direction' => '0deg',
				),
				'parallax'      => '0',
			),
			'dependency' => $fourfeatures_button,
		) : null,

		( 'four-column-features' === $posts_layout ) ? array(
			'id'    => 'fourfeatures_section_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( '4 Column Features General Stylings', 'startup' ),
		) : null,

		( 'four-column-features' === $posts_layout ) ? array(
			'id'       => 'home_section_padding_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Padding', 'startup' ),
			'sub_desc' => esc_html__( 'Set 4 Column Features section padding from here.', 'startup' ),
			'std'      => array(
				'top'    => '160px',
				'right'  => '0',
				'bottom' => '135px',
				'left'   => '0',
			),
		) : null,

		( 'four-column-features' === $posts_layout ) ? array(
			'id'       => 'home_section_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Margin', 'startup' ),
			'sub_desc' => esc_html__( 'Set 4 Column Features section margin from here.', 'startup' ),
			'std'      => array(
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
				'left'   => '0',
			),
		) : null,

		( 'four-column-features' === $posts_layout ) ? array(
			'id'       => 'home_section_background_' . $unique_id,
			'type'     => 'background',
			'title'    => esc_html__( '4 Column Features Background', 'startup' ),
			'sub_desc' => esc_html__( 'Set background color, pattern and image from here.', 'startup' ),
			'options'  => array(
				'color'         => '',            // false to disable, not needed otherwise.
				'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
				'image_upload'  => '',            // false to disable, not needed otherwise.
				'repeat'        => array(),       // false to disable, array of options to override default ( optional ).
				'attachment'    => array(),       // false to disable, array of options to override default ( optional ).
				'position'      => array(),       // false to disable, array of options to override default ( optional ).
				'size'          => array(),       // false to disable, array of options to override default ( optional ).
				'gradient'      => '',            // false to disable, not needed otherwise.
				'parallax'      => array(),       // false to disable, array of options to override default ( optional ).
			),
			'std'      => array(
				'color'         => '#ffffff',
				'use'           => 'pattern',
				'image_pattern' => 'nobg',
				'image_upload'  => '',
				'repeat'        => 'no-repeat',
				'attachment'    => 'scroll',
				'position'      => 'left top',
				'size'          => 'cover',
				'gradient'      => array(
					'from'      => '#ffffff',
					'to'        => '#000000',
					'direction' => '0deg',
				),
				'parallax'      => '0',
			),
		) : null,

		( 'four-column-features' === $posts_layout ) ? array(
			'id'    => 'fourfeatures_heading_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Heading Font', 'startup' ),
			'std'   => array(
				'preview-text'  => 'Heading Font',
				'preview-color' => ' light',
				'font-family'   => 'Montserrat',
				'font-weight'   => '500',
				'color'         => '#091e42',
				'font-size'     => '27px',
				'line-height'   => '1.2',
				'css-selectors' => '.layout-' . $unique_id . '.fourfeatures-section h2',
			),
		) : null,

		( 'four-column-features' === $posts_layout ) ? array(
			'id'    => 'fourfeatures_subheading_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Subheading Font', 'startup' ),
			'std'   => array(
				'preview-text'  => 'Subheading Font',
				'preview-color' => 'light',
				'font-family'   => 'Montserrat',
				'font-weight'   => '400',
				'color'         => '#505f79',
				'font-size'     => '14px',
				'line-height'   => '25px',
				'css-selectors' => '.layout-' . $unique_id . '.fourfeatures-section p.sub-heading',
			),
		) : null,

		( 'four-column-features' === $posts_layout ) ? array(
			'id'    => 'fourfeatures_title_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Title Font', 'startup' ),
			'std'   => array(
				'preview-text'  => 'Title',
				'preview-color' => 'light',
				'font-family'   => 'Montserrat',
				'font-weight'   => '500',
				'color'         => '#091e42',
				'font-size'     => '20px',
				'line-height'   => '1.2',
				'css-selectors' => '.layout-' . $unique_id . '.fourfeatures-section h3',
			),
		) : null,

		( 'four-column-features' === $posts_layout ) ? array(
			'id'    => 'fourfeatures_text_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Text Font', 'startup' ),
			'std'   => array(
				'preview-text'  => 'Text',
				'preview-color' => 'light',
				'font-family'   => 'Montserrat',
				'font-weight'   => '400',
				'color'         => '#505f79',
				'font-size'     => '14px',
				'line-height'   => '25px',
				'css-selectors' => '.layout-' . $unique_id . '.fourfeatures-section p.text',
			),
		) : null,

		/**
		 * Homepage Section - CTA
		 *
		 * @package Startup
		 */

		( 'cta' === $posts_layout ) ? array(
			'id'       => 'cta_title_' . $unique_id,
			'type'     => 'text',
			'title'    => esc_html__( 'CTA Title', 'startup' ),
			'sub_desc' => esc_html__( 'Enter CTA title from here', 'startup' ),
			'std'      => 'Our products have been used by millions of people worldwide',
		) : null,

		( 'cta' === $posts_layout ) ? array(
			'id'       => 'cta_text_' . $unique_id,
			'type'     => 'textarea',
			'title'    => esc_html__( 'Text', 'startup' ),
			'sub_desc' => esc_html__( 'Enter text from here', 'startup' ),
			'std'      => 'Sign up to our email list to get notified about new launches and offers',
		) : null,

		( 'cta' === $posts_layout ) ? array(
			'id'       => 'cta_button_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Show Features Button', 'startup' ),
			'sub_desc' => wp_kses( __( 'Use this button to Show or Hide the <strong>Features</strong> button completely.', 'startup' ), array( 'strong' => '' ) ),
			'std'      => '1',
		) : null,

		( 'cta' === $posts_layout ) ? array(
			'id'         => 'cta_button_text_' . $unique_id,
			'type'       => 'text',
			'title'      => esc_html__( 'Button Text', 'startup' ),
			'sub_desc'   => esc_html__( 'Enter button text.', 'startup' ),
			'std'        => esc_html__( 'Sign Up Now', 'startup' ),
			'dependency' => $cta_button,
		) : null,

		( 'cta' === $posts_layout ) ? array(
			'id'         => 'cta_button_url_' . $unique_id,
			'type'       => 'text',
			'title'      => esc_html__( 'Button URL', 'startup' ),
			'sub_desc'   => esc_html__( 'Enter button URL.', 'startup' ),
			'std'        => '#',
			'dependency' => $cta_button,
		) : null,

		( 'cta' === $posts_layout ) ? array(
			'id'         => 'cta_button_padding_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Button Padding', 'startup' ),
			'sub_desc'   => esc_html__( 'Set Button padding from here.', 'startup' ),
			'std'        => array(
				'top'    => '0px',
				'right'  => '0px',
				'bottom' => '0px',
				'left'   => '0px',
			),
			'dependency' => $cta_button,
		) : null,

		( 'cta' === $posts_layout ) ? array(
			'id'         => 'cta_button_color_' . $unique_id,
			'type'       => 'color',
			'title'      => esc_html__( 'Button Color', 'startup' ),
			'sub_desc'   => esc_html__( 'The icon color will also be shown as hover state background color on features item.', 'startup' ),
			'std'        => '#ffffff',
			'dependency' => $cta_button,
		) : null,

		( 'cta' === $posts_layout ) ? array(
			'id'         => 'cta_button_bg_' . $unique_id,
			'type'       => 'background',
			'title'      => esc_html__( 'Button Background', 'startup' ),
			'sub_desc'   => esc_html__( 'Set buttons background color, pattern and image from here.', 'startup' ),
			'options'    => array(
				'color'         => '',            // false to disable, not needed otherwise.
				'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
				'image_upload'  => '',            // false to disable, not needed otherwise.
				'repeat'        => array(),       // false to disable, array of options to override default ( optional ).
				'attachment'    => array(),       // false to disable, array of options to override default ( optional ).
				'position'      => array(),       // false to disable, array of options to override default ( optional ).
				'size'          => array(),       // false to disable, array of options to override default ( optional ).
				'gradient'      => '',            // false to disable, not needed otherwise.
				'parallax'      => array(),       // false to disable, array of options to override default ( optional ).
			),
			'std'        => array(
				'color'         => '#00B8D9',
				'use'           => 'gradient',
				'image_pattern' => 'nobg',
				'image_upload'  => '',
				'repeat'        => 'repeat',
				'attachment'    => 'scroll',
				'position'      => '',
				'size'          => 'cover',
				'gradient'      => array(
					'from'      => '#00B8D9',
					'to'        => '#79E2F2',
					'direction' => '-82.012deg',
				),
				'parallax'      => '0',
			),
			'dependency' => $cta_button,
		) : null,

		( 'cta' === $posts_layout ) ? array(
			'id'    => 'cta_section_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'CTA General Stylings', 'startup' ),
		) : null,

		( 'cta' === $posts_layout ) ? array(
			'id'       => 'home_section_padding_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Padding', 'startup' ),
			'sub_desc' => esc_html__( 'Set CTA padding from here.', 'startup' ),
			'std'      => array(
				'top'    => '80px',
				'right'  => '0',
				'bottom' => '80px',
				'left'   => '0',
			),
		) : null,

		( 'cta' === $posts_layout ) ? array(
			'id'       => 'home_section_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Margin', 'startup' ),
			'sub_desc' => esc_html__( 'Set CTA margin from here.', 'startup' ),
			'std'      => array(
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
				'left'   => '0',
			),
		) : null,

		( 'cta' === $posts_layout ) ? array(
			'id'       => 'home_section_background_' . $unique_id,
			'type'     => 'background',
			'title'    => esc_html__( 'CTA Background', 'startup' ),
			'sub_desc' => esc_html__( 'Set background color, pattern and image from here.', 'startup' ),
			'options'  => array(
				'color'         => '',            // false to disable, not needed otherwise.
				'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
				'image_upload'  => '',            // false to disable, not needed otherwise.
				'repeat'        => array(),       // false to disable, array of options to override default ( optional ).
				'attachment'    => array(),       // false to disable, array of options to override default ( optional ).
				'position'      => array(),       // false to disable, array of options to override default ( optional ).
				'size'          => array(),       // false to disable, array of options to override default ( optional ).
				'gradient'      => '',            // false to disable, not needed otherwise.
				'parallax'      => array(),       // false to disable, array of options to override default ( optional ).
			),
			'std'      => array(
				'color'         => '',
				'use'           => 'upload',
				'image_pattern' => 'nobg',
				'image_upload'  => get_template_directory_uri() . '/images/cta-bg.jpg',
				'repeat'        => 'no-repeat',
				'attachment'    => 'scroll',
				'position'      => 'left top',
				'size'          => 'cover',
				'gradient'      => array(
					'from'      => '#ffffff',
					'to'        => '#000000',
					'direction' => '0deg',
				),
				'parallax'      => '0',
			),
		) : null,

		( 'cta' === $posts_layout ) ? array(
			'id'    => 'cta_title_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Title Font', 'startup' ),
			'std'   => array(
				'preview-text'  => 'Title',
				'preview-color' => 'dark',
				'font-family'   => 'Montserrat',
				'font-weight'   => '500',
				'color'         => '#ffffff',
				'font-size'     => '27px',
				'line-height'   => '1.2',
				'css-selectors' => '.layout-' . $unique_id . '.cta-section h3',
			),
		) : null,

		( 'cta' === $posts_layout ) ? array(
			'id'    => 'cta_text_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Text Font', 'startup' ),
			'std'   => array(
				'preview-text'  => 'Text',
				'preview-color' => 'dark',
				'font-family'   => 'Montserrat',
				'font-weight'   => '400',
				'color'         => '#ffffff',
				'font-size'     => '14px',
				'line-height'   => '25px',
				'css-selectors' => '.layout-' . $unique_id . '.cta-section p',
			),
		) : null,


		/**
		 * Homepage Section - 4 Column Features
		 *
		 * @package Startup
		 */

		( 'pricing' === $posts_layout ) ? array(
			'id'       => 'pricing_heading_' . $unique_id,
			'type'     => 'text',
			'title'    => esc_html__( 'Heading', 'startup' ),
			'sub_desc' => esc_html__( 'Enter heading from here', 'startup' ),
			'std'      => 'Startup like no other',
		) : null,

		( 'pricing' === $posts_layout ) ? array(
			'id'       => 'pricing_subheading_' . $unique_id,
			'type'     => 'textarea',
			'title'    => esc_html__( 'Subheading', 'startup' ),
			'sub_desc' => esc_html__( 'Enter subheading from here', 'startup' ),
			'std'      => 'Also people love our app for these wonderfull and efficient features which give the user a complete',
		) : null,

		( 'pricing' === $posts_layout ) ? array(
			'id'        => 'home_pricing_' . $unique_id,
			'type'      => 'group',
			'title'     => esc_html__( 'Pricing Table', 'startup' ),
			'sub_desc'  => esc_html__( 'Add Pricing item appearing on the homepage Pricing Table.', 'startup' ),
			'groupname' => esc_html__( 'Features', 'startup' ),
			'subfields' => array(
				array(
					'id'    => 'pricing_title_' . $unique_id,
					'type'  => 'text',
					'title' => esc_html__( 'Title', 'startup' ),
				),
				array(
					'id'    => 'pricing_icon_' . $unique_id,
					'type'  => 'icon_select',
					'title' => esc_html__( 'Icon', 'startup' ),
				),
				array(
					'id'    => 'pricing_icon_bg_' . $unique_id,
					'type'  => 'color',
					'title' => esc_html__( 'Icon background color', 'startup' ),
					'std'   => '#ffffff',
				),
				array(
					'id'       => 'pricing_icon_color_' . $unique_id,
					'type'     => 'color',
					'title'    => esc_html__( 'Icon color', 'startup' ),
					'std'      => '#637bfd',
					'sub_desc' => esc_html__( 'Select icon color from here. The same color will be shown at other places on Pricing Table item and on hover state background color.', 'startup' ),
				),
				array(
					'id'       => 'pricing_text_' . $unique_id,
					'type'     => 'textarea',
					'title'    => esc_html__( 'Features List', 'startup' ),
					'sub_desc' => wp_kses( __( 'Enter Features list in Pricing table. <strong>One item per line</strong> and Enter <strong>Full lank line</strong> to show new features list.', 'startup' ), array( 'strong' => '' ) ),
				),
				array(
					'id'    => 'pricing_amount_' . $unique_id,
					'type'  => 'text',
					'title' => esc_html__( 'Price', 'startup' ),
				),
				array(
					'id'    => 'pricing_amount_color_' . $unique_id,
					'type'  => 'color',
					'title' => esc_html__( 'Price Color', 'startup' ),
					'std'   => '#637bfd',
				),
				array(
					'id'       => 'pricing_button_text_' . $unique_id,
					'type'     => 'text',
					'title'    => esc_html__( 'Button Text', 'startup' ),
					'sub_desc' => esc_html__( 'Enter button text.', 'startup' ),
				),
				array(
					'id'       => 'pricing_button_url_' . $unique_id,
					'type'     => 'text',
					'title'    => esc_html__( 'Button URL', 'startup' ),
					'sub_desc' => esc_html__( 'Enter button URL.', 'startup' ),
				),
				array(
					'id'    => 'pricing_table_bg_' . $unique_id,
					'type'  => 'color',
					'title' => esc_html__( 'Table Background Color', 'startup' ),
					'std'   => '#e9effe',
				),
				array(
					'id'    => 'pricing_table_title_color_' . $unique_id,
					'type'  => 'color',
					'title' => esc_html__( 'Table Title color', 'startup' ),
					'std'   => '#091e42',
				),
				array(
					'id'    => 'pricing_table_text_color_' . $unique_id,
					'type'  => 'color',
					'title' => esc_html__( 'Table Text color', 'startup' ),
					'std'   => '#505f79',
				),
			),
			'std'       => array(
				'1' => array(
					'group_sort'                         => '1',
					'pricing_title_' . $unique_id        => 'Starter',
					'pricing_icon_' . $unique_id         => 'braille',
					'pricing_icon_bg_' . $unique_id      => '#ffffff',
					'pricing_icon_color_' . $unique_id   => '#637bfd',
					'pricing_text_' . $unique_id         => $pricing_list,
					'pricing_amount_' . $unique_id       => '$12',
					'pricing_amount_color_' . $unique_id => '#637bfd',
					//'pricing_button_color_' . $unique_id => '#ffffff',
					'pricing_button_text_' . $unique_id  => 'Sign Up Now',
					'pricing_button_url_' . $unique_id   => '#',
					'pricing_table_bg_' . $unique_id     => '#e9effe',
					'pricing_table_title_color_' . $unique_id => '#091e42',
					'pricing_table_text_color_' . $unique_id => '#505f79',
				),
				'2' => array(
					'group_sort'                         => '2',
					'pricing_title_' . $unique_id        => 'Enterprise',
					'pricing_icon_' . $unique_id         => 'free-code-camp',
					'pricing_icon_bg_' . $unique_id      => '#f4f8ff',
					'pricing_icon_color_' . $unique_id   => '#637bfd',
					'pricing_text_' . $unique_id         => $pricing_list,
					'pricing_amount_' . $unique_id       => '$22',
					'pricing_amount_color_' . $unique_id => '#ffffff',
					//'pricing_button_color_' . $unique_id => '#ffffff',
					'pricing_button_text_' . $unique_id  => 'Sign Up Now',
					'pricing_button_url_' . $unique_id   => '#',
					'pricing_table_bg_' . $unique_id     => '#637bfd',
					'pricing_table_title_color_' . $unique_id => '#ffffff',
					'pricing_table_text_color_' . $unique_id => '#ffffff',
				),
				'3' => array(
					'group_sort'                         => '3',
					'pricing_title_' . $unique_id        => 'Professional',
					'pricing_icon_' . $unique_id         => 'line-chart',
					'pricing_icon_bg_' . $unique_id      => '#ffffff',
					'pricing_icon_color_' . $unique_id   => '#637bfd',
					'pricing_text_' . $unique_id         => $pricing_list,
					'pricing_amount_' . $unique_id       => '$30',
					'pricing_amount_color_' . $unique_id => '#637bfd',
					//'pricing_button_color_' . $unique_id => '#ffffff',
					'pricing_button_text_' . $unique_id  => 'Sign Up Now',
					'pricing_button_url_' . $unique_id   => '#',
					'pricing_table_bg_' . $unique_id     => '#e9effe',
					'pricing_table_title_color_' . $unique_id => '#091e42',
					'pricing_table_text_color_' . $unique_id => '#505f79',
				),
			),
		) : null,

		( 'pricing' === $posts_layout ) ? array(
			'id'       => 'pricing_button_bg_' . $unique_id,
			'type'     => 'background',
			'title'    => esc_html__( 'Button Background', 'startup' ),
			'sub_desc' => esc_html__( 'Set buttons background color, pattern and image from here.', 'startup' ),
			'options'  => array(
				'color'         => '',            // false to disable, not needed otherwise.
				'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
				'image_upload'  => '',            // false to disable, not needed otherwise.
				'repeat'        => array(),       // false to disable, array of options to override default ( optional ).
				'attachment'    => array(),       // false to disable, array of options to override default ( optional ).
				'position'      => array(),       // false to disable, array of options to override default ( optional ).
				'size'          => array(),       // false to disable, array of options to override default ( optional ).
				'gradient'      => '',            // false to disable, not needed otherwise.
				'parallax'      => array(),       // false to disable, array of options to override default ( optional ).
			),
			'std'      => array(
				'color'         => '#00B8D9',
				'use'           => 'gradient',
				'image_pattern' => 'nobg',
				'image_upload'  => '',
				'repeat'        => 'repeat',
				'attachment'    => 'scroll',
				'position'      => '',
				'size'          => 'cover',
				'gradient'      => array(
					'from'      => '#00B8D9',
					'to'        => '#79E2F2',
					'direction' => '-83.453deg',
				),
				'parallax'      => '0',
			),
		) : null,

		( 'pricing' === $posts_layout ) ? array(
			'id'    => 'pricing_button_color_' . $unique_id,
			'type'  => 'color',
			'title' => esc_html__( 'Button Color', 'startup' ),
			'std'   => '#ffffff',
		) : null,

		( 'pricing' === $posts_layout ) ? array(
			'id'    => 'pricing_section_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Pricing General Stylings', 'startup' ),
		) : null,

		( 'pricing' === $posts_layout ) ? array(
			'id'       => 'home_section_padding_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Padding', 'startup' ),
			'sub_desc' => esc_html__( 'Set Pricing section padding from here.', 'startup' ),
			'std'      => array(
				'top'    => '160px',
				'right'  => '0',
				'bottom' => '30px',
				'left'   => '0',
			),
		) : null,

		( 'pricing' === $posts_layout ) ? array(
			'id'       => 'home_section_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Margin', 'startup' ),
			'sub_desc' => esc_html__( 'Set Pricing section margin from here.', 'startup' ),
			'std'      => array(
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
				'left'   => '0',
			),
		) : null,

		( 'pricing' === $posts_layout ) ? array(
			'id'       => 'home_section_background_' . $unique_id,
			'type'     => 'background',
			'title'    => esc_html__( 'Pricing Table Background', 'startup' ),
			'sub_desc' => esc_html__( 'Set background color, pattern and image from here.', 'startup' ),
			'options'  => array(
				'color'         => '',            // false to disable, not needed otherwise.
				'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
				'image_upload'  => '',            // false to disable, not needed otherwise.
				'repeat'        => array(),       // false to disable, array of options to override default ( optional ).
				'attachment'    => array(),       // false to disable, array of options to override default ( optional ).
				'position'      => array(),       // false to disable, array of options to override default ( optional ).
				'size'          => array(),       // false to disable, array of options to override default ( optional ).
				'gradient'      => '',            // false to disable, not needed otherwise.
				'parallax'      => array(),       // false to disable, array of options to override default ( optional ).
			),
			'std'      => array(
				'color'         => '',
				'use'           => 'gradient',
				'image_pattern' => 'nobg',
				'image_upload'  => '',
				'repeat'        => 'no-repeat',
				'attachment'    => 'scroll',
				'position'      => 'left top',
				'size'          => 'cover',
				'gradient'      => array(
					'from'      => '#f4f8ff',
					'to'        => '#ffffff',
					'direction' => '-90deg',
				),
				'parallax'      => '0',
			),
		) : null,

		( 'pricing' === $posts_layout ) ? array(
			'id'    => 'pricing_heading_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Heading Font', 'startup' ),
			'std'   => array(
				'preview-text'  => 'Heading Font',
				'preview-color' => ' light',
				'font-family'   => 'Montserrat',
				'font-weight'   => '500',
				'color'         => '#091e42',
				'font-size'     => '27px',
				'line-height'   => '1.2',
				'css-selectors' => '.layout-' . $unique_id . '.pricing-section h2',
			),
		) : null,

		( 'pricing' === $posts_layout ) ? array(
			'id'    => 'pricing_subheading_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Subheading Font', 'startup' ),
			'std'   => array(
				'preview-text'  => 'Subheading Font',
				'preview-color' => 'light',
				'font-family'   => 'Montserrat',
				'font-weight'   => '400',
				'color'         => '#505f79',
				'font-size'     => '14px',
				'line-height'   => '25px',
				'css-selectors' => '.layout-' . $unique_id . '.pricing-section p.sub-heading',
			),
		) : null,

		( 'pricing' === $posts_layout ) ? array(
			'id'    => 'pricing_title_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Title Font', 'startup' ),
			'std'   => array(
				'preview-text'  => 'Title',
				'preview-color' => 'light',
				'font-family'   => 'Montserrat',
				'font-weight'   => '500',
				'font-size'     => '20px',
				'line-height'   => '1.2',
				'css-selectors' => '.layout-' . $unique_id . '.pricing-section h3',
			),
		) : null,

		( 'pricing' === $posts_layout ) ? array(
			'id'    => 'pricing_text_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Text Font', 'startup' ),
			'std'   => array(
				'preview-text'  => 'Text',
				'preview-color' => 'light',
				'font-family'   => 'Montserrat',
				'font-weight'   => '400',
				'font-size'     => '14px',
				'line-height'   => '40px',
				'css-selectors' => '.layout-' . $unique_id . '.pricing-section .pricing-list p',
			),
		) : null,

		( 'pricing' === $posts_layout ) ? array(
			'id'    => 'pricing_amount_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Price Font', 'startup' ),
			'std'   => array(
				'preview-text'   => 'Price Font',
				'preview-color'  => 'light',
				'font-family'    => 'Montserrat',
				'font-weight'    => '500',
				'font-size'      => '27px',
				'letter-spacing' => '2px',
				'css-selectors'  => '.layout-' . $unique_id . '.pricing-section .pricing-amount',
			),
		) : null,

		/**
		 * Homepage Section - Clients
		 *
		 * @package Startup
		 */

		( 'clients' === $posts_layout ) ? array(
			'id'       => 'clients_heading_' . $unique_id,
			'type'     => 'text',
			'title'    => esc_html__( 'Heading', 'startup' ),
			'sub_desc' => esc_html__( 'Enter heading from here.', 'startup' ),
			'std'      => 'Check out some of our clients',
		) : null,

		( 'clients' === $posts_layout ) ? array(
			'id'       => 'clients_subheading_' . $unique_id,
			'type'     => 'textarea',
			'title'    => esc_html__( 'Subheading', 'startup' ),
			'sub_desc' => esc_html__( 'Enter subheading from here.', 'startup' ),
			'std'      => 'Our themes have been used on some of the most recognized names on the web. Here are some of our clients.',
		) : null,

		( 'clients' === $posts_layout ) ? array(
			'id'        => 'home_clients_' . $unique_id,
			'type'      => 'group',
			'title'     => esc_html__( 'Clients Items', 'startup' ),
			'groupname' => esc_html__( 'Client Item', 'startup' ),
			'subfields' => array(
				array(
					'id'    => 'client_title_' . $unique_id,
					'type'  => 'text',
					'title' => esc_html__( 'Title', 'startup' ),
				),
				array(
					'id'       => 'client_image_' . $unique_id,
					'type'     => 'upload',
					'title'    => esc_html__( 'Image', 'startup' ),
					'sub_desc' => esc_html__( 'Upload or select an image for partner. Recommended Size(190X70px)', 'startup' ),
				),
				array(
					'id'       => 'client_link_' . $unique_id,
					'type'     => 'text',
					'title'    => esc_html__( 'Link', 'startup' ),
					'sub_desc' => esc_html__( 'Insert a link URL of partner', 'startup' ),
					'std'      => '#',
				),
			),
			'std'       => array(
				'1' => array(
					'group_sort'                 => '1',
					'client_title_' . $unique_id => 'PS4',
					'client_image_' . $unique_id => get_template_directory_uri() . '/images/ps4.png',
					'client_link_' . $unique_id  => '#',
				),
				'2' => array(
					'group_sort'                 => '2',
					'client_title_' . $unique_id => 'Dell',
					'client_image_' . $unique_id => get_template_directory_uri() . '/images/dell.png',
					'client_link_' . $unique_id  => '#',
				),
				'3' => array(
					'group_sort'                 => '3',
					'client_title_' . $unique_id => 'Pioneer',
					'client_image_' . $unique_id => get_template_directory_uri() . '/images/pioneer.png',
					'client_link_' . $unique_id  => '#',
				),
				'4' => array(
					'group_sort'                 => '4',
					'client_title_' . $unique_id => 'PS4',
					'client_image_' . $unique_id => get_template_directory_uri() . '/images/ps4.png',
					'client_link_' . $unique_id  => '#',
				),
				'5' => array(
					'group_sort'                 => '5',
					'client_title_' . $unique_id => 'Dell',
					'client_image_' . $unique_id => get_template_directory_uri() . '/images/dell.png',
					'client_link_' . $unique_id  => '#',
				),
			),
		) : null,

		// Post Container.
		( 'clients' === $posts_layout ) ? array(
			'id'    => 'mts_post_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Container', 'startup' ),
		) : null,

		( 'clients' === $posts_layout ) ? array(
			'id'       => 'home_section_background_' . $unique_id,
			'type'     => 'background',
			'title'    => esc_html__( 'Clients Background', 'startup' ),
			'sub_desc' => esc_html__( 'Set background color, pattern and image from here.', 'startup' ),
			'options'  => array(
				'color'         => '',            // false to disable, not needed otherwise.
				'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
				'image_upload'  => '',            // false to disable, not needed otherwise.
				'repeat'        => array(),       // false to disable, array of options to override default ( optional ).
				'attachment'    => array(),       // false to disable, array of options to override default ( optional ).
				'position'      => array(),       // false to disable, array of options to override default ( optional ).
				'size'          => array(),       // false to disable, array of options to override default ( optional ).
				'gradient'      => '',            // false to disable, not needed otherwise.
				'parallax'      => array(),       // false to disable, array of options to override default ( optional ).
			),
			'std'      => array(
				'color'         => '#ffffff',
				'use'           => 'pattern',
				'image_pattern' => 'nobg',
				'image_upload'  => '',
				'repeat'        => 'no-repeat',
				'attachment'    => 'scroll',
				'position'      => 'left top',
				'size'          => 'cover',
				'gradient'      => array(
					'from'      => '#ffffff',
					'to'        => '#000000',
					'direction' => '0deg',
				),
				'parallax'      => '0',
			),
		) : null,

		( 'clients' === $posts_layout ) ? array(
			'id'       => 'home_section_padding_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Padding', 'startup' ),
			'sub_desc' => esc_html__( 'Set clients section padding from here.', 'startup' ),
			'std'      => array(
				'top'    => '80px',
				'right'  => '0',
				'bottom' => '160px',
				'left'   => '0',
			),
		) : null,

		( 'clients' === $posts_layout ) ? array(
			'id'       => 'home_section_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Margin', 'startup' ),
			'sub_desc' => esc_html__( 'Set clients section margin from here.', 'startup' ),
			'std'      => array(
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
				'left'   => '0',
			),
		) : null,

		( 'clients' === $posts_layout ) ? array(
			'id'    => 'clients_heading_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Heading Font', 'startup' ),
			'std'   => array(
				'preview-text'  => 'Heading Font',
				'preview-color' => 'light',
				'font-family'   => 'Montserrat',
				'font-weight'   => '500',
				'color'         => '#091e42',
				'font-size'     => '27px',
				'line-height'   => '1.1',
				'css-selectors' => '.layout-' . $unique_id . ' .clients-heading-section h2',
			),
		) : null,

		( 'clients' === $posts_layout ) ? array(
			'id'    => 'clients_subheading_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Subheading Font', 'startup' ),
			'std'   => array(
				'preview-text'  => 'Subheading Font',
				'preview-color' => 'light',
				'font-family'   => 'Montserrat',
				'font-weight'   => '400',
				'color'         => '#505f79',
				'font-size'     => '14px',
				'line-height'   => '25px',
				'css-selectors' => '.layout-' . $unique_id . ' .clients-heading-section p.sub-heading',
			),
		) : null,

		/**
		 * Homepage Section - Testimonials
		 *
		 * @package Startup
		 */

		( 'testimonials' === $posts_layout ) ? array(
			'id'       => 'testimonials_heading_' . $unique_id,
			'type'     => 'text',
			'title'    => esc_html__( 'Heading', 'startup' ),
			'sub_desc' => esc_html__( 'Enter heading from here.', 'startup' ),
			'std'      => 'Customer Reviews',
		) : null,

		( 'testimonials' === $posts_layout ) ? array(
			'id'       => 'testimonials_subheading_' . $unique_id,
			'type'     => 'textarea',
			'title'    => esc_html__( 'Subheading', 'startup' ),
			'sub_desc' => esc_html__( 'Enter subheading from here.', 'startup' ),
			'std'      => 'Our service is as good as our themes. Here is what our customers have to say about us.',
		) : null,

		( 'testimonials' === $posts_layout ) ? array(
			'id'        => 'home_testimonials_' . $unique_id,
			'type'      => 'group',
			'title'     => esc_html__( 'Testimonials', 'startup' ),
			'sub_desc'  => esc_html__( 'Add customer reviews appearing on the homepage Testimonials section.', 'startup' ),
			'groupname' => esc_html__( 'Testimonial', 'startup' ),
			'subfields' => array(
				array(
					'id'       => 'customer_title_' . $unique_id,
					'type'     => 'text',
					'title'    => esc_html__( 'Name', 'startup' ),
					'sub_desc' => esc_html__( 'Enter customer name from here.', 'startup' ),
				),
				array(
					'id'       => 'customer_image_' . $unique_id,
					'type'     => 'upload',
					'title'    => esc_html__( 'Profile Pic', 'startup' ),
					'sub_desc' => esc_html__( 'Upload customer profile pic from here. Recommended size: 100 x 100 in px', 'startup' ),
					'return'   => 'url',
				),
				array(
					'id'       => 'customer_profession_' . $unique_id,
					'type'     => 'text',
					'title'    => esc_html__( 'Profession', 'startup' ),
					'sub_desc' => esc_html__( 'Enter customer profession from here.', 'startup' ),
				),
				array(
					'id'    => 'customer_link_' . $unique_id,
					'type'  => 'text',
					'title' => esc_html__( 'URL', 'startup' ),
				),
				array(
					'id'       => 'customer_description_' . $unique_id,
					'type'     => 'textarea',
					'title'    => esc_html__( 'Customer Review', 'startup' ),
					'sub_desc' => esc_html__( 'Enter customer review from here.', 'startup' ),
				),
			),
			'std'       => array(
				'1' => array(
					'group_sort'                         => '1',
					'customer_title_' . $unique_id       => 'Bobby Kim',
					'customer_profession_' . $unique_id  => 'Senior Developer',
					'customer_image_' . $unique_id       => get_template_directory_uri() . '/images/customer-1.png',
					'customer_link_' . $unique_id        => '#',
					'customer_description_' . $unique_id => esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore', 'startup' ),
				),
				'2' => array(
					'group_sort'                         => '2',
					'customer_title_' . $unique_id       => 'Devin Lawrence',
					'customer_profession_' . $unique_id  => 'Blogger',
					'customer_image_' . $unique_id       => get_template_directory_uri() . '/images/customer-2.png',
					'customer_link_' . $unique_id        => '#',
					'customer_description_' . $unique_id => esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore', 'startup' ),
				),
				'3' => array(
					'group_sort'                         => '3',
					'customer_title_' . $unique_id       => 'Rodney Powers',
					'customer_profession_' . $unique_id  => 'Trainer',
					'customer_image_' . $unique_id       => get_template_directory_uri() . '/images/customer-3.png',
					'customer_link_' . $unique_id        => '#',
					'customer_description_' . $unique_id => esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore', 'startup' ),
				),
			),
		) : null,

		( 'testimonials' === $posts_layout ) ? array(
			'id'       => 'testimonials_border_radius_' . $unique_id,
			'type'     => 'text',
			'class'    => 'small-text',
			'title'    => esc_html__( 'Profile Pic Border Radius', 'startup' ),
			'sub_desc' => esc_html__( 'Update pic border radius in px.', 'startup' ),
			'std'      => '100',
			'args'     => array( 'type' => 'number' ),
		) : null,

		// Post Container.
		( 'testimonials' === $posts_layout ) ? array(
			'id'    => 'mts_post_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Container', 'startup' ),
		) : null,

		( 'testimonials' === $posts_layout ) ? array(
			'id'       => 'home_section_background_' . $unique_id,
			'type'     => 'background',
			'title'    => esc_html__( 'Customer Reviews background', 'startup' ),
			'sub_desc' => esc_html__( 'Set Testimonials section background color, pattern and image from here.', 'startup' ),
			'options'  => array(
				'color'         => '',            // false to disable, not needed otherwise.
				'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
				'image_upload'  => '',            // false to disable, not needed otherwise.
				'repeat'        => array(),       // false to disable, array of options to override default ( optional ).
				'attachment'    => array(),       // false to disable, array of options to override default ( optional ).
				'position'      => array(),       // false to disable, array of options to override default ( optional ).
				'size'          => array(),       // false to disable, array of options to override default ( optional ).
				'gradient'      => '',            // false to disable, not needed otherwise.
				'parallax'      => array(),       // false to disable, array of options to override default ( optional ).
			),
			'std'      => array(
				'color'         => '#ffffff',
				'use'           => 'upload',
				'image_pattern' => 'nobg',
				'image_upload'  => get_template_directory_uri() . '/images/testimonials-bg.jpg',
				'repeat'        => 'repeat',
				'attachment'    => 'scroll',
				'position'      => 'left top',
				'size'          => 'cover',
				'gradient'      => array(
					'from'      => '#ffffff',
					'to'        => '#000000',
					'direction' => '0deg',
				),
				'parallax'      => '0',
			),
		) : null,

		( 'testimonials' === $posts_layout ) ? array(
			'id'       => 'home_section_padding_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Padding', 'startup' ),
			'sub_desc' => esc_html__( 'Set Teams section padding from here.', 'startup' ),
			'std'      => array(
				'top'    => '150px',
				'right'  => '0',
				'bottom' => '80px',
				'left'   => '0',
			),
		) : null,

		( 'testimonials' === $posts_layout ) ? array(
			'id'       => 'home_section_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Margin', 'startup' ),
			'sub_desc' => esc_html__( 'Set Teams section margin from here.', 'startup' ),
			'std'      => array(
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
				'left'   => '0',
			),
		) : null,

		( 'testimonials' === $posts_layout ) ? array(
			'id'    => 'testimonials_heading_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Heading Font', 'startup' ),
			'std'   => array(
				'preview-text'  => 'Heading Font',
				'preview-color' => 'dark',
				'font-family'   => 'Montserrat',
				'font-weight'   => '500',
				'color'         => '#ffffff',
				'font-size'     => '27px',
				'line-height'   => '1.2',
				'css-selectors' => '.layout-' . $unique_id . '.testimonials-section h2',
			),
		) : null,

		( 'testimonials' === $posts_layout ) ? array(
			'id'    => 'testimonials_subheading_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Subheading Font', 'startup' ),
			'std'   => array(
				'preview-text'  => 'Subheading Font',
				'preview-color' => 'dark',
				'font-family'   => 'Montserrat',
				'font-weight'   => '400',
				'color'         => '#ffffff',
				'font-size'     => '14px',
				'line-height'   => '25px',
				'css-selectors' => '.layout-' . $unique_id . '.testimonials-section p.sub-heading',
			),
		) : null,

		( 'testimonials' === $posts_layout ) ? array(
			'id'    => 'testimonials_name_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Name Font', 'startup' ),
			'std'   => array(
				'preview-text'  => 'Customer Name',
				'preview-color' => 'light',
				'font-family'   => 'Montserrat',
				'font-weight'   => '700',
				'color'         => '#091e42',
				'font-size'     => '16px',
				'line-height'   => '1.2',
				'css-selectors' => '.layout-' . $unique_id . ' .testimonial-item h3',
			),
		) : null,

		( 'testimonials' === $posts_layout ) ? array(
			'id'    => 'testimonials_profession_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Profession Font', 'startup' ),
			'std'   => array(
				'preview-text'  => 'Customer Profession',
				'preview-color' => 'light',
				'font-family'   => 'Montserrat',
				'font-weight'   => '500',
				'color'         => startup_get_settings( 'primary_color_scheme' ),
				'font-size'     => '14px',
				'css-selectors' => '.layout-' . $unique_id . ' p.customer-profession',
			),
		) : null,

		( 'testimonials' === $posts_layout ) ? array(
			'id'    => 'testimonials_desc_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Customer Reviews Font', 'startup' ),
			'std'   => array(
				'preview-text'  => 'Customer Reviews',
				'preview-color' => 'light',
				'font-family'   => 'Montserrat',
				'font-weight'   => '400',
				'color'         => '#091e42',
				'font-size'     => '16px',
				'line-height'   => '25px',
				'css-selectors' => '.layout-' . $unique_id . ' p.customer-description',
			),
		) : null,

		/**
		 * Homepage Section - Counters
		 *
		 * @package Startup
		 */

		( 'counters' === $posts_layout ) ? array(
			'id'       => 'counters_heading_' . $unique_id,
			'type'     => 'text',
			'title'    => esc_html__( 'Heading', 'startup' ),
			'sub_desc' => esc_html__( 'Enter heading from here', 'startup' ),
			'std'      => 'About MyThemeShop',
		) : null,

		( 'counters' === $posts_layout ) ? array(
			'id'       => 'counters_subheading_' . $unique_id,
			'type'     => 'textarea',
			'title'    => esc_html__( 'Subheading', 'startup' ),
			'sub_desc' => esc_html__( 'Enter subheading from here', 'startup' ),
			'std'      => 'With years of experience in creating WordPress products, we\'ve created hundreds of world-class themes and plugins, reaching millions of people around the globe.',
		) : null,

		( 'counters' === $posts_layout ) ? array(
			'id'        => 'home_counters_' . $unique_id,
			'type'      => 'group',
			'title'     => esc_html__( 'Counters', 'startup' ),
			'sub_desc'  => esc_html__( 'Add Counter item appearing on the Counters section.', 'startup' ),
			'groupname' => esc_html__( 'Counter', 'startup' ),
			'subfields' => array(
				array(
					'id'    => 'counter_title_' . $unique_id,
					'type'  => 'text',
					'title' => esc_html__( 'Title', 'startup' ),
				),
				array(
					'id'    => 'counter_number_' . $unique_id,
					'type'  => 'text',
					'title' => esc_html__( 'Text', 'startup' ),
				),
			),
			'std'       => array(
				'1' => array(
					'group_sort'                   => '1',
					'counter_title_' . $unique_id  => 'Happy Users',
					'counter_number_' . $unique_id => '600000',
				),
				'2' => array(
					'group_sort'                   => '2',
					'counter_title_' . $unique_id  => 'Themes & Plugins',
					'counter_number_' . $unique_id => '140',
				),
				'3' => array(
					'group_sort'                   => '3',
					'counter_title_' . $unique_id  => 'Support Ques Answered',
					'counter_number_' . $unique_id => '57000',
				),
				'4' => array(
					'group_sort'                   => '4',
					'counter_title_' . $unique_id  => 'New Releases in last Year',
					'counter_number_' . $unique_id => '30',
				),
			),
		) : null,

		( 'counters' === $posts_layout ) ? array(
			'id'    => 'counters_section_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Counters General Stylings', 'startup' ),
		) : null,

		( 'counters' === $posts_layout ) ? array(
			'id'       => 'home_section_padding_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Padding', 'startup' ),
			'sub_desc' => esc_html__( 'Set Counters section padding from here.', 'startup' ),
			'std'      => array(
				'top'    => '160px',
				'right'  => '0',
				'bottom' => '120px',
				'left'   => '0',
			),
		) : null,

		( 'counters' === $posts_layout ) ? array(
			'id'       => 'home_section_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Margin', 'startup' ),
			'sub_desc' => esc_html__( 'Set Counters section margin from here.', 'startup' ),
			'std'      => array(
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
				'left'   => '0',
			),
		) : null,

		( 'counters' === $posts_layout ) ? array(
			'id'       => 'home_section_background_' . $unique_id,
			'type'     => 'background',
			'title'    => esc_html__( 'Counters Background', 'startup' ),
			'sub_desc' => esc_html__( 'Set background color, pattern and image from here.', 'startup' ),
			'options'  => array(
				'color'         => '',            // false to disable, not needed otherwise.
				'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
				'image_upload'  => '',            // false to disable, not needed otherwise.
				'repeat'        => array(),       // false to disable, array of options to override default ( optional ).
				'attachment'    => array(),       // false to disable, array of options to override default ( optional ).
				'position'      => array(),       // false to disable, array of options to override default ( optional ).
				'size'          => array(),       // false to disable, array of options to override default ( optional ).
				'gradient'      => '',            // false to disable, not needed otherwise.
				'parallax'      => array(),       // false to disable, array of options to override default ( optional ).
			),
			'std'      => array(
				'color'         => '#ffffff',
				'use'           => 'pattern',
				'image_pattern' => 'nobg',
				'image_upload'  => '',
				'repeat'        => 'no-repeat',
				'attachment'    => 'scroll',
				'position'      => 'left top',
				'size'          => 'cover',
				'gradient'      => array(
					'from'      => '#ffffff',
					'to'        => '#000000',
					'direction' => '0deg',
				),
				'parallax'      => '0',
			),
		) : null,

		( 'counters' === $posts_layout ) ? array(
			'id'    => 'counters_heading_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Heading Font', 'startup' ),
			'std'   => array(
				'preview-text'  => 'Heading Font',
				'preview-color' => 'light',
				'font-family'   => 'Montserrat',
				'font-weight'   => '500',
				'color'         => '#091e42',
				'font-size'     => '27px',
				'line-height'   => '1.2',
				'css-selectors' => '.layout-' . $unique_id . '.counters-section h2',
			),
		) : null,

		( 'counters' === $posts_layout ) ? array(
			'id'    => 'counters_subheading_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Subheading Font', 'startup' ),
			'std'   => array(
				'preview-text'  => 'Subheading Font',
				'preview-color' => 'light',
				'font-family'   => 'Montserrat',
				'font-weight'   => '400',
				'color'         => '#505f79',
				'font-size'     => '14px',
				'line-height'   => '25px',
				'css-selectors' => '.layout-' . $unique_id . '.counters-section p.sub-heading',
			),
		) : null,

		( 'counters' === $posts_layout ) ? array(
			'id'    => 'counters_title_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Title Font', 'startup' ),
			'std'   => array(
				'preview-text'  => 'Title',
				'preview-color' => 'light',
				'font-family'   => 'Montserrat',
				'font-weight'   => '400',
				'color'         => '#505f79',
				'font-size'     => '14px',
				'line-height'   => '1',
				'css-selectors' => '.layout-' . $unique_id . '.counters-section h3',
			),
		) : null,

		( 'counters' === $posts_layout ) ? array(
			'id'    => 'counters_number_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Numbers Font', 'startup' ),
			'std'   => array(
				'preview-text'  => 'Text',
				'preview-color' => 'light',
				'font-family'   => 'Montserrat',
				'font-weight'   => '700',
				'color'         => '#637bfd',
				'font-size'     => '27px',
				'line-height'   => '1.1',
				'css-selectors' => '.layout-' . $unique_id . '.counters-section p.counter-number',
			),
		) : null,

		/**
		 * Homepage Section - Blog
		 *
		 * @package Startup
		 */

		( 'blog' === $posts_layout ) ? array(
			'id'       => 'blog_section_heading_' . $unique_id,
			'type'     => 'text',
			'title'    => esc_html__( 'Heading', 'startup' ),
			'sub_desc' => esc_html__( 'Enter heading from here.', 'startup' ),
			'std'      => 'Check out some blog pages',
		) : null,

		( 'blog' === $posts_layout ) ? array(
			'id'       => 'blog_section_subheading_' . $unique_id,
			'type'     => 'textarea',
			'title'    => esc_html__( 'Subheading', 'startup' ),
			'sub_desc' => esc_html__( 'Enter subheading from here.', 'startup' ),
			'std'      => 'Our service is as good as our themes. Here is what our customers have to say about us',
		) : null,

		( 'blog' === $posts_layout ) ? array(
			'id'       => 'blog_section_postnum_' . $unique_id,
			'type'     => 'text',
			'title'    => esc_html__( 'Blog Posts Number', 'startup' ),
			'sub_desc' => esc_html__( 'Enter the total number of posts which you want to show on Blog Section.', 'startup' ),
			'validate' => 'numeric',
			'std'      => '3',
			'class'    => 'small-text',
			'args'     => array( 'type' => 'number' ),
		) : null,

		// Meta info.
		( 'blog' === $posts_layout ) ? array(
			'id'    => 'post_meta_info_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Meta Info', 'startup' ),
		) : null,

		( 'blog' === $posts_layout ) ? array(
			'id'       => 'mts_front_headline_meta_info' . $unique_id,
			'type'     => 'layout2',
			// translators: title.
			'title'    => sprintf( wp_kses_post( __( '%s Meta Info', 'startup' ) ), $title ),
			// translators: description.
			'sub_desc' => sprintf( wp_kses_post( __( 'Organize how you want the post meta info to appear on %s', 'startup' ) ), $title ),
			'options'  => array(
				'enabled'  => array(
					'author'   => array(
						'label'     => __( 'Author Name', 'startup' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_author_icon_front_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'startup' ),
							),
						),
					),
					'date'     => array(
						'label'     => esc_html__( 'Date', 'startup' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_date_icon_front_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'startup' ),
							),
						),
					),
					'category' => array(
						'label'     => esc_html__( 'Categories', 'startup' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_category_icon_front_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'startup' ),
							),
						),
					),
				),
				'disabled' => array(
					'comment' => array(
						'label'     => esc_html__( 'Comment Count', 'startup' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_comment_icon_front_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'startup' ),
								'std'   => 'comment-o',
							),
						),
					),
				),
			),
			'std'      => array(
				'enabled'  => array(
					'author'   => array(
						'label'     => __( 'Author Name', 'startup' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_author_icon_front_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'startup' ),
							),
						),
					),
					'date'     => array(
						'label'     => esc_html__( 'Date', 'startup' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_date_icon_front_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'startup' ),
							),
						),
					),
					'category' => array(
						'label'     => esc_html__( 'Categories', 'startup' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_category_icon_front_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'startup' ),
							),
						),
					),
				),
				'disabled' => array(
					'comment' => array(
						'label'     => esc_html__( 'Comment Count', 'startup' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_comment_icon_front_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'startup' ),
								'std'   => 'comment-o',
							),
						),
					),
				),
			),
		) : null,

		( 'blog' === $posts_layout ) ? array(
			'id'       => 'mts_meta_info_margin_front_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Margin', 'startup' ),
			'sub_desc' => esc_html__( 'Post Meta Info margin.', 'startup' ),
			'std'      => array(
				'top'    => '14px',
				'right'  => '0',
				'bottom' => '5px',
				'left'   => '0',
			),
		) : null,

		( 'blog' === $posts_layout ) ? array(
			'id'       => 'mts_meta_info_padding_front_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Padding', 'startup' ),
			'sub_desc' => esc_html__( 'Post Meta Info padding.', 'startup' ),
			'std'      => array(
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
				'left'   => '0',
			),
		) : null,

		( 'blog' === $posts_layout ) ? array(
			'id'    => 'meta_info_front_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Meta Info Typography', 'startup' ),
			'std'   => array(
				'preview-text'  => 'Post Meta Info Font',
				'preview-color' => 'light',
				'font-family'   => 'Montserrat',
				'font-weight'   => '400',
				'font-size'     => '14px',
				'line-height'   => '1',
				'color'         => startup_get_settings( 'primary_color_scheme' ),
				'css-selectors' => '.layout-' . $unique_id . ' .layout-grid .post-info, .layout-' . $unique_id . ' .layout-grid .post-info span a',
			),
		) : null,

		// Post Container.
		( 'blog' === $posts_layout ) ? array(
			'id'    => 'mts_post_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Container', 'startup' ),
		) : null,

		( 'blog' === $posts_layout ) ? array(
			'id'       => 'home_section_background_' . $unique_id,
			'type'     => 'background',
			'title'    => esc_html__( 'Section Background', 'startup' ),
			'sub_desc' => esc_html__( 'Set background color, pattern and image from here.', 'startup' ),
			'options'  => array(
				'color'         => '',            // false to disable, not needed otherwise.
				'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
				'image_upload'  => '',            // false to disable, not needed otherwise.
				'repeat'        => array(),       // false to disable, array of options to override default ( optional ).
				'attachment'    => array(),       // false to disable, array of options to override default ( optional ).
				'position'      => array(),       // false to disable, array of options to override default ( optional ).
				'size'          => array(),       // false to disable, array of options to override default ( optional ).
				'gradient'      => '',            // false to disable, not needed otherwise.
				'parallax'      => array(),       // false to disable, array of options to override default ( optional ).
			),
			'std'      => array(
				'color'         => '#f4f8ff',
				'use'           => 'pattern',
				'image_pattern' => 'nobg',
				'image_upload'  => '',
				'repeat'        => 'no-repeat',
				'attachment'    => 'scroll',
				'position'      => 'center center',
				'size'          => 'cover',
				'gradient'      => array(
					'from'      => '#ffffff',
					'to'        => '#000000',
					'direction' => '0deg',
				),
				'parallax'      => '0',
			),
		) : null,

		( 'blog' === $posts_layout ) ? array(
			'id'       => 'home_section_padding_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Padding', 'startup' ),
			'sub_desc' => esc_html__( 'Set blog section padding from here.', 'startup' ),
			'std'      => array(
				'top'    => '155px',
				'right'  => '0',
				'bottom' => '115px',
				'left'   => '0',
			),
		) : null,

		( 'blog' === $posts_layout ) ? array(
			'id'       => 'home_section_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Margin', 'startup' ),
			'sub_desc' => esc_html__( 'Set blog section margin from here.', 'startup' ),
			'std'      => array(
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
				'left'   => '0',
			),
		) : null,

		( 'blog' === $posts_layout ) ? array(
			'id'    => 'blog_heading_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Heading Font', 'startup' ),
			'std'   => array(
				'preview-text'  => 'Heading Font',
				'preview-color' => 'light',
				'font-family'   => 'Montserrat',
				'font-weight'   => '500',
				'color'         => '#091e42',
				'font-size'     => '27px',
				'line-height'   => '1.1',
				'css-selectors' => '.layout-' . $unique_id . ' .blog-heading-section h2',
			),
		) : null,

		( 'blog' === $posts_layout ) ? array(
			'id'    => 'blog_subheading_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Subheading Font', 'startup' ),
			'std'   => array(
				'preview-text'  => 'Subheading Font',
				'preview-color' => 'light',
				'font-family'   => 'Montserrat',
				'font-weight'   => '400',
				'color'         => '#505f79',
				'font-size'     => '14px',
				'line-height'   => '25px',
				'css-selectors' => '.layout-' . $unique_id . ' .blog-heading-section p.sub-heading',
			),
		) : null,

		( 'blog' === $posts_layout ) ? array(
			'id'    => 'blog_title_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Title Font', 'startup' ),
			'std'   => array(
				'preview-text'  => 'Title',
				'preview-color' => 'light',
				'font-family'   => 'Montserrat',
				'font-weight'   => '700',
				'color'         => '#091e42',
				'font-size'     => '16px',
				'line-height'   => '1.5',
				'css-selectors' => '.layout-' . $unique_id . ' .layout-grid h3 a',
			),
		) : null,

	);
endforeach;
